@@ -75,6 +75,7 @@ OC.L10N.register(
     "On events happening in a <strong>Circle</strong> of which you are a member" : "Olyan eseményekről, amelyek olyan <strong>körben</strong> zajlanak, amelynek tagja",
     "Any important event in a <strong>Circle</strong> you are moderating" : "Bármely fontos eseményről, amely olyan <strong>körben</strong> történt, melyeket moderál",
     "On global events happening in any <strong>Circle</strong>" : "Bármely <strong>körben</strong> zajló globális eseményekről",
+    "Shared to Circles" : "Körökkel megosztva",
     "Single" : "Egyéni",
     "Personal" : "Személyes",
     "System" : "Rendszer",
@@ -120,16 +121,14 @@ OC.L10N.register(
     "%s shared multiple files with \"%s\"." : "%s több fájlt osztott a következővel: „%s”.",
     "%s shared multiple files with you." : "%s több fájlt osztott meg Önnel.",
     "Boot up" : "Rendszerindítás",
-    "Initialisation Nextcloud" : "A Nextcloud előkészítése",
-    "Initialisation Circles App" : "A Körök alkalmazás előkészítése",
+    "Nextcloud Initialization" : "A Nextcloud előkészítése",
+    "Circles App Initialization" : "Körök alkalmazás előkészítése",
     "Fresh installation status" : "Friss előkészítési állapot",
     "Building Local Database" : "Helyi adatbázis építése",
     "Testing Basic Circle Creation" : "Alapvető körlétrehozás tesztelése",
     "Adding local users and moderators" : "Helyi felhasználók és moderátorok hozzáadása",
     "Circle not found" : "A Kör nem található",
     "Circle not found " : "A Kör nem található ",
-    "A circle with that name exists" : "Már van ilyen nevű kör",
-    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "A Körök alkalmazás nem használható, amíg a rendszergazda legalább egy körtípust nem engedélyez.",
     "This member does not exist" : "Ez a tag nem létezik",
     "This account is already a member of the circle" : "A fiók már tagja a körnek",
     "Federated link not found" : "A föderált kapcsolat nem található",
@@ -155,6 +154,7 @@ OC.L10N.register(
     "Personal Circle" : "Személyes kör",
     "%s owned by %s" : "a(z) %s tulajdonosa %s",
     "You need a specify a type of circle" : "Meg kell adnia egy körtípust",
+    "A circle with that name exists" : "Már van ilyen nevű kör",
     "This member is not the owner of the circle" : "Ez a tag nem a kör tulajdonosa",
     "This member is not an admin of the circle" : "Ez a tag nem a kör adminisztrátora",
     "Group contains too many members" : "A csoport túl sok tagot tartalmaz",
@@ -174,7 +174,6 @@ OC.L10N.register(
     "Password to access content shared with you by %1$s" : "Jelszó a(z) %1$s által megosztott tartalom eléréséhez",
     "Password to access content" : "Jelszó a tartalom eléréséhez",
     "This item is already shared with this circle" : "Ez az elem már megosztásra került ezzel a körrel",
-    "Could not find share" : "A megosztás nem található",
     "Bring cloud-users closer together." : "Közelebb hozza a felhőfelhasználókat.",
     "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "A Körök lehetővé teszi, hogy az emberek létrehozzák a saját köreiket a felhasználóinak/kollégáinak/barátaiknak.\nEzeket a csoportokat (vagy „köröket”) aztán bármely más alkalmazás használhatja megosztási célokra.",
     "No files in here" : "Itt nincsenek fájlok",
@@ -182,11 +181,9 @@ OC.L10N.register(
     "Name" : "Név",
     "Size" : "Méret",
     "Modified" : "Módosítva",
-    "Nextcloud User" : "Nextcloud felhasználó",
-    "This user is already a member of the circle" : "Ez a felhasználó már tagja a körnek",
-    "The user is already a member of this circle" : "A felhasználó már tagja a körnek",
-    "The user has already been invited into this circle" : "A felhasználó már meg lett hívva a körbe",
-    "This user does not exist" : "Ez a felhasználó nem létezik",
-    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "A Körök lehetővé teszi, hogy a felhasználók létrehozzák a saját köreiket a felhasználóknak/kollégáknak/barátoknak.\nEzeket a felhasználói csoportokat (vagy „körök”) aztán bármely más alkalmazás használhatja megosztási célokra."
+    "Initialisation Nextcloud" : "A Nextcloud előkészítése",
+    "Initialisation Circles App" : "A Körök alkalmazás előkészítése",
+    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "A Körök alkalmazás nem használható, amíg a rendszergazda legalább egy körtípust nem engedélyez.",
+    "Could not find share" : "A megosztás nem található"
 },
 "nplurals=2; plural=(n != 1);");
