@@ -1,17 +1,14 @@
 OC.L10N.register(
     "files",
     {
-    "Storage is temporarily not available" : "Konservejo dumtempe ne disponeblas",
-    "Storage invalid" : "Konservejo ne validas",
-    "Unknown error" : "Nekonata eraro",
     "File could not be found" : "Dosiero ne troveblas",
     "Move or copy" : "Movi aŭ kopii",
     "Download" : "Elŝuti",
     "Delete" : "Forigi",
     "Tags" : "Etikedoj",
+    "Show list view" : "Montri listan vidon",
     "Home" : "Hejmo",
     "Close" : "Fermi",
-    "Favorites" : "Pliŝatataj",
     "Could not create folder \"{dir}\"" : "Ne eblas krei dosierujon „{dir}“",
     "This will stop your current uploads." : "Tio haltigos viajn nunajn alŝutojn.",
     "Upload cancelled." : "La alŝuto nuliĝis.",
@@ -32,6 +29,7 @@ OC.L10N.register(
     "Move" : "Movi",
     "Copy" : "Kopii",
     "Choose target folder" : "Elekti celan dosierujon",
+    "Edit locally" : "Redakti loke",
     "Open" : "Malfermi",
     "Delete file" : "Forigi dosieron",
     "Delete folder" : "Forigi dosierujon",
@@ -43,6 +41,7 @@ OC.L10N.register(
     "Unable to determine date" : "Ne eblas determini daton",
     "This operation is forbidden" : "Ĉi tiu operacio malpermesatas",
     "This directory is unavailable, please check the logs or contact the administrator" : "Ĉi tiu dosierujo maldisponeblas, bonvolu kontroli la protokolojn aŭ kontakti la administranton",
+    "Storage is temporarily not available" : "Konservejo dumtempe ne disponeblas",
     "Could not move \"{file}\", target exists" : "Ne eblas movi la dosieron „{file}“, celo jam ekzistas",
     "Could not move \"{file}\"" : "Ne eblas movi la dosieron „{file}“",
     "copy" : "kopio",
@@ -68,6 +67,7 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["inkluzive %n kaŝita","inkluzive %n kaŝita(j)"],
     "_Uploading %n file_::_Uploading %n files_" : ["Alŝutatas %n dosiero","Alŝutatas %n dosieroj"],
     "Select file range" : "Elekti dosierintervalon",
+    "{used}%" : "{used}%",
     "{used} of {quota} used" : "{used} uzataj el {quota}",
     "{used} used" : "{used} uzataj",
     "\"{name}\" is an invalid file name." : "„{name}“ estas nevalida dosiernomo.",
@@ -75,14 +75,13 @@ OC.L10N.register(
     "\"/\" is not allowed inside a file name." : "Ne eblas uziĝi „/“ en dosiernomo.",
     "\"{name}\" is not an allowed filetype" : "„{name}“ ne estas permesita dosiertipo.",
     "View in folder" : "Vidi en dosierujo",
-    "Copied!" : "Kopiita!",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Kopii senperan ligilon (nur validas por uzantoj, kiuj povas aliri al tiu dosiero aŭ dosierujo)",
     "Path" : "Vojo",
     "_%n byte_::_%n bytes_" : ["%n bajto","%n bajtoj"],
     "Favorited" : "Pliŝatitaj",
     "Favorite" : "Pliŝatata",
-    "You can only favorite a single file or folder at a time" : "Vi povas samtempe pliŝatigi nur unu dosieron aŭ dosierujon",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Kopii senperan ligilon (nur validas por uzantoj, kiuj povas aliri al tiu dosiero aŭ dosierujo)",
     "New folder" : "Nova dosierujo",
+    "Create new folder" : "Krei novan dosierujon",
     "Upload file" : "Alŝuti dosieron",
     "Recent" : "Lastaj ŝanĝoj",
     "Not favorited" : "Ne pliŝatitaj",
@@ -93,6 +92,7 @@ OC.L10N.register(
     "Removed from favorites" : "Forigita el pliŝataĵoj",
     "You added {file} to your favorites" : "Vi aldonis {file} al viaj pliŝataĵoj",
     "You removed {file} from your favorites" : "Vi forigis {file} el viaj pliŝataĵoj",
+    "Favorites" : "Pliŝatataj",
     "File changes" : "Dosierŝanĝoj",
     "Created by {user}" : "Kreita de {user}",
     "Changed by {user}" : "Ŝanĝita de {user}",
@@ -123,42 +123,51 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "Dosiero aldoniĝis aŭ foriĝis el viaj <strong>pliŝataĵoj</strong>",
     "A file or folder has been <strong>changed</strong>" : "Dosiero aŭ dosierujo <strong>ŝanĝiĝis</strong>",
     "All files" : "Ĉiuj dosieroj",
-    "Unlimited" : "Senlima",
     "Upload (max. %s)" : "Alŝuti (maks. %s)",
     "Accept" : "Akcepti",
     "Reject" : "Rifuzi",
     "in %s" : "en %s",
     "File Management" : "Dosieradministrado",
+    "File name" : "Dosiernomo",
+    "Name cannot be empty" : "Nomo ne povas mapleni",
+    "Select all" : "Elekti ĉion",
     "Change" : "Ŝanĝi",
-    "Unable to change the favourite state of the file" : "Ne eblas ŝanĝi la staton pri pliŝatataĵo de la dosiero",
-    "Error while loading the file data" : "Eraro dum ŝargo de la dosierdatumoj",
-    "Cancel" : "Nuligi",
-    "Create" : "Krei",
-    "%s used" : "%s uzataj",
-    "%1$s of %2$s used" : "%1$s uzataj el %2$s",
-    "Show hidden files" : "Montri kaŝitajn dosierojn",
-    "WebDAV" : "WebDAV",
-    "Toggle grid view" : "Baskuligi kradan vidon",
+    "New owner" : "Nova posedanto",
+    "Unknown error" : "Nekonata eraro",
     "No files in here" : "Neniu dosiero ĉi tie",
     "Upload some content or sync with your devices!" : "Alŝutu iom da enhavo aŭ sinkronigu kun viaj aparatoj!",
-    "No entries found in this folder" : "Neniu enigo troviĝis en ĉi tiu dosierujo",
-    "Select all" : "Elekti ĉion",
-    "Upload too large" : "Alŝuto tro granda",
-    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "La dosieroj, kiujn vi provas alŝuti, transpasas la maksimuman grandon por dosieralŝutoj en ĉi tiu servilo.",
+    "Go back" : "Reveni",
+    "Show hidden files" : "Montri kaŝitajn dosierojn",
+    "Additional settings" : "Plia agordo",
+    "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "Kopii tondejen",
+    "Unable to change the favourite state of the file" : "Ne eblas ŝanĝi la staton pri pliŝatataĵo de la dosiero",
+    "Error while loading the file data" : "Eraro dum ŝargo de la dosierdatumoj",
+    "Create" : "Krei",
+    "Creating file" : "Kreante dosieron",
+    "Delete permanently" : "Forigi por ĉiam",
+    "Open details" : "Montri detalojn",
+    "Templates" : "Ŝablonoj",
     "No favorites yet" : "Ankoraŭ neniu pliŝataĵo",
     "Files and folders you mark as favorite will show up here" : "Dosieroj kaj dosierujoj, kiujn vi markas kiel pliŝataĵoj, aperos ĉi tie",
+    "Toggle grid view" : "Baskuligi kradan vidon",
+    "No entries found in this folder" : "Neniu enigo troviĝis en ĉi tiu dosierujo",
+    "Upload too large" : "Alŝuto tro granda",
+    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "La dosieroj, kiujn vi provas alŝuti, transpasas la maksimuman grandon por dosieralŝutoj en ĉi tiu servilo.",
+    "Text file" : "Tekstodosiero",
+    "New text file.txt" : "Nova tekstodosiero.txt",
+    "Storage invalid" : "Konservejo ne validas",
+    "You can only favorite a single file or folder at a time" : "Vi povas samtempe pliŝatigi nur unu dosieron aŭ dosierujon",
+    "Unlimited" : "Senlima",
+    "Search users" : "Serĉi uzantojn",
+    "Cancel" : "Nuligi",
+    "%s used" : "%s uzataj",
+    "%1$s of %2$s used" : "%1$s uzataj el %2$s",
     "Deleted files" : "Forigitaj dosieroj",
     "Shares" : "Kunhavigoj",
     "Shared with others" : "Kunhavata kun aliaj",
     "Shared with you" : "Kunhavata kun vi",
     "Shared by link" : "Kunhavata per ligilo",
-    "Deleted shares" : "Forigitaj kunhavigoj",
-    "Text file" : "Tekstodosiero",
-    "New text file.txt" : "Nova tekstodosiero.txt",
-    "Select" : "Elekti",
-    "You don’t have permission to upload or create files here" : "Vi ne permesatas alŝuti aŭ krei dosierojn ĉi tie",
-    "New" : "Nova",
-    "%s%% of %s used" : "%s%% el %s uzataj",
-    "Settings" : "Agordo"
+    "Deleted shares" : "Forigitaj kunhavigoj"
 },
 "nplurals=2; plural=(n != 1);");
