@@ -1,9 +1,6 @@
 OC.L10N.register(
     "files",
     {
-    "Storage is temporarily not available" : "Tallennustila on tilapäisesti pois käytöstä",
-    "Storage invalid" : "Virheellinen tallennustila",
-    "Unknown error" : "Tuntematon virhe",
     "File could not be found" : "Tiedostoa ei löytynyt",
     "Move or copy" : "Siirrä tai kopioi",
     "Download" : "Lataa",
@@ -13,7 +10,6 @@ OC.L10N.register(
     "Show grid view" : "Näytä ruudukkonäkymä",
     "Home" : "Koti",
     "Close" : "Sulje",
-    "Favorites" : "Suosikit",
     "Could not create folder \"{dir}\"" : "Kansiota \"{dir}\" ei voitu luoda",
     "This will stop your current uploads." : "Tämä pysäyttää meneillään olevat lähetykset.",
     "Upload cancelled." : "Lähetys peruttu.",
@@ -53,6 +49,7 @@ OC.L10N.register(
     "Unable to determine date" : "Päivämäärän määrittäminen epäonnistui",
     "This operation is forbidden" : "Tämä toiminto on kielletty",
     "This directory is unavailable, please check the logs or contact the administrator" : "Hakemisto ei ole käytettävissä. Tarkista lokit tai ole yhteydessä ylläpitoon.",
+    "Storage is temporarily not available" : "Tallennustila on tilapäisesti pois käytöstä",
     "Could not move \"{file}\", target exists" : "Tiedoston \"{file}\" siirtäminen ei onnistunut, kohde on olemassa",
     "Could not move \"{file}\"" : "Tiedoston \"{file}\" siirtäminen ei onnistunut",
     "copy" : "kopio",
@@ -60,6 +57,7 @@ OC.L10N.register(
     "Could not copy \"{file}\"" : "Tiedostoa \"{file}\" ei voitu kopioida",
     "Copied {origin} inside {destination}" : "Kopioitu {origin} kohteeseen {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopioitu {origin} ja {nbfiles} muuta tiedostoa kohteeseen {destination}",
+    "Failed to redirect to client" : "Uudelleenohjaus asiakkaaseen epäonnistui",
     "{newName} already exists" : "{newName} on jo olemassa",
     "Could not rename \"{fileName}\", it does not exist any more" : "Tiedoston \"{fileName}\" nimeäminen uudelleen ei onnistunut, koska sitä ei ole enää olemassa",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nimi \"{targetName}\" on jo käytössä kansiossa \"{dir}\". Valitse toinen nimi.",
@@ -99,16 +97,18 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Tallennustila on melkein täynnä ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["vastaa \"{filter}\"","vastaa \"{filter}\""],
     "View in folder" : "Näe kansiossa",
-    "Copied!" : "Kopioitu!",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Kopioi suora linkki (toimii vain käyttäjillä, joilla on pääsyoikeus tähän tiedostoon/kansioon)",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Suoralinkki kopioitiin (toimii vain niillä käyttäjillä, joilla on pääsy kyseiseen tiedostoon/kansioon)",
     "Path" : "Polku",
     "_%n byte_::_%n bytes_" : ["%n tavu","%n tavua"],
     "Favorited" : "Lisätty suosikkeihin",
     "Favorite" : "Suosikki",
-    "You can only favorite a single file or folder at a time" : "Voit valita suosikiksi vain yhden tiedoston tai kansion kerrallaan",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Kopioi suora linkki (toimii vain käyttäjillä, joilla on pääsyoikeus tähän tiedostoon/kansioon)",
     "New folder" : "Uusi kansio",
+    "Create new folder" : "Luo uusi kansio",
     "Upload file" : "Lähetä tiedosto",
     "Recent" : "Viimeaikaiset",
+    "This file has the tag {tag}" : "Tällä tiedostolla on tunniste {tag}",
+    "This file has the tags {firstTags} and {lastTag}" : "Tällä tiedostolla on tunnisteet {firstTags} ja {lastTag}",
     "Not favorited" : "Ei suosikeissa",
     "Remove from favorites" : "Poista suosikeista",
     "Add to favorites" : "Lisää suosikkeihin",
@@ -117,6 +117,7 @@ OC.L10N.register(
     "Removed from favorites" : "Poistettu suosikeista",
     "You added {file} to your favorites" : "Lisäsit tiedoston {file} suosikkeihin",
     "You removed {file} from your favorites" : "Poistit tiedoston {file} suosikeista",
+    "Favorites" : "Suosikit",
     "File changes" : "Tiedostomuutokset",
     "Created by {user}" : "Tekijänä {user}",
     "Changed by {user}" : "Muokkaajana {user}",
@@ -154,7 +155,6 @@ OC.L10N.register(
     "A file or folder has been <strong>changed</strong>" : "Tiedostoa tai kansiota on <strong>muutettu</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Suosikkitiedostoa tai -kansiota on <strong>muutettu</strong>",
     "All files" : "Kaikki tiedostot",
-    "Unlimited" : "Rajoittamaton",
     "Upload (max. %s)" : "Lähetys (enintään %s)",
     "Accept" : "Hyväksy",
     "Reject" : "Hylkää",
@@ -168,46 +168,91 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Kohteen {path} omistajuussiirto käyttäjältä {user} valmistui.",
     "in %s" : "polussa %s",
     "File Management" : "Tiedostohallinta",
+    "Reload current directory" : "Lataa nykyinen kansio uudelleen",
+    "Go to the \"{dir}\" directory" : "Siirry kansioon \"{dir}\"",
+    "Rename file" : "Nimeä tiedosto uudelleen",
+    "File name" : "Tiedostonimi",
+    "A long time ago" : "Kauan aikaa sitten",
+    "Download file {name}" : "Lataa tiedosto {name}",
+    "\"{name}\" is not an allowed filetype." : "\"{name}\" ei ole sallittu tiedostotyyppi.",
+    "{newName} already exists." : "{newName} on jo olemassa.",
+    "Name cannot be empty" : "Nimi ei voi olla tyhjä",
+    "Another entry with the same name already exists" : "Toinen tietue samalla nimellä on jo olemassa",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Kohteen \"{oldName}\" uudeksi nimeksi asetettiin \"{newName}\"",
+    "Could not rename \"{oldName}\"" : "Ei voitu nimetä uudelleen \"{oldName}\"",
+    "Select all" : "Valitse kaikki",
+    "Unselect all" : "Poista valinnat",
+    "ascending" : "nousevasti",
+    "descending" : "laskevasti",
+    "Sort list by {column} ({direction})" : "Järjestä luettelo sarakkeen {column} mukaan ({direction})",
+    "List of files and folders." : "Luettelo tiedostoista ja kansioista.",
+    "Storage informations" : "Tallennustilan tietoja",
+    "{usedQuotaByte} used" : "{usedQuotaByte} käytetty",
+    "{relative}% used" : "{relative} % käytetty",
+    "Could not refresh storage stats" : "Tallennustilan tilastoja ei voitu päivittää",
     "Transfer ownership of a file or folder" : "Siirrä tiedoston tai kansion omistajuus",
     "Choose file or folder to transfer" : "Valitse siirrettävä tiedosto tai kansio",
     "Change" : "Muuta",
     "New owner" : "Uusi omistaja",
-    "Search users" : "Etsi käyttäjistä",
     "Choose a file or folder to transfer" : "Valitse siirrettävä tiedosto tai kansio",
     "Transfer" : "Siirrä",
     "Transfer {path} to {userid}" : "Siirrä {path} käyttäjälle {userid}",
     "Invalid path selected" : "Valittu virheellinen polku",
+    "Unknown error" : "Tuntematon virhe",
     "Ownership transfer request sent" : "Pyyntö omistajuuden vaihdosta lähetetty",
     "Cannot transfer ownership of a file or folder you do not own" : "Et voi siirtää sellaisen tiedoston tai kansion omistajuutta, jota et itse omista",
+    "Select file or folder to link to" : "Valitse tiedosto tai kansio, johon linkitetään",
+    "Loading current folder" : "Ladataan nykyistä kansiota",
+    "No files in here" : "Täällä ei ole tiedostoja",
+    "Upload some content or sync with your devices!" : "Lähetä tiedostoja tai synkronoi sisältö laitteidesi kanssa!",
+    "Go to the previous folder" : "Siirry edelliseen kansioon",
+    "Go back" : "Mene takaisin",
+    "Open the files app settings" : "Avaa tiedostosovelluksen asetukset",
+    "Files settings" : "Tiedostojen asetukset",
+    "File cannot be accessed" : "Tiedostoa ei voi käyttää",
+    "You might not have have permissions to view it, ask the sender to share it" : "Oikeutesi eivät kenties riitä sen katseluun, pyydä lähettäjää jakamaan se",
+    "Sort favorites first" : "Järjestä suosikit ensiksi",
+    "Show hidden files" : "Näytä piilotetut tiedostot",
+    "Crop image previews" : "Rajaa kuvien esikatseluja",
+    "Additional settings" : "Lisäasetukset",
+    "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "Kopioi leikepöydälle",
+    "Use this address to access your Files via WebDAV" : "Käytä tätä osoitetta yhdistääksesi tiedostosi WebDAV:in kautta",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Jos sinulla on kaksivaiheinen todennus käytössä, sinun täytyy luoda uusi sovellussalasana ja käyttää sitä napsauttamalla tästä.",
+    "Clipboard is not available" : "Leikepöytä ei ole käytettävissä",
+    "WebDAV URL copied to clipboard" : "WebDAV-osoite kopioitu leikepöydälle",
     "Unable to change the favourite state of the file" : "Suosikki-tilan muuttaminen epäonnistui.",
     "Error while loading the file data" : "Virhe tiedostoa ladatessa",
     "Pick a template for {name}" : "Valtise mallipohja tiedostolle {name}",
-    "Cancel" : "Peruuta",
     "Create" : "Luo",
     "Create a new file with the selected template" : "Luo uusi tiedosto valitulla mallipohjalla",
     "Creating file" : "Luodaan tiedostoa",
     "Blank" : "Tyhjä",
     "Unable to create new file from template" : "Uutta tiedostoa mallipohjasta ei voi luoda",
+    "Delete permanently" : "Poista pysyvästi",
+    "Open folder {displayName}" : "Avaa kansio {displayName}",
+    "Open details" : "Avaa yksityiskohdat",
     "Set up templates folder" : "Aseta mallipohjien kansio",
     "Templates" : "Mallipohjat",
+    "Create new templates folder" : "Luo uusi mallipohjien kansio",
     "Unable to initialize the templates directory" : "Mallipohjien kansiota ei voitu alustaa",
+    "List of favorites files and folders." : "Luettelo suosikkitiedostoista ja -kansioista.",
+    "No favorites yet" : "Ei vielä suosikkeja",
+    "Files and folders you mark as favorite will show up here" : "Suosikeiksi merkitsemäsi tiedostot ja kansiot näkyvät täällä",
+    "Toggle grid view" : "Ruudukkonäkymä päälle/pois",
+    "No entries found in this folder" : "Ei kohteita tässä kansiossa",
+    "Upload too large" : "Lähetettävä tiedosto on liian suuri",
+    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Lähetettäväksi valitsemasi tiedostot ylittävät palvelimen salliman tiedostokoon rajan.",
+    "Text file" : "Tekstitiedosto",
+    "New text file.txt" : "Uusi tekstitiedosto.txt",
+    "Storage invalid" : "Virheellinen tallennustila",
+    "You can only favorite a single file or folder at a time" : "Voit valita suosikiksi vain yhden tiedoston tai kansion kerrallaan",
+    "Unlimited" : "Rajoittamaton",
+    "Search users" : "Etsi käyttäjistä",
+    "Cancel" : "Peruuta",
     "%s used" : "%s käytetty",
     "%s%%" : "%s%%",
     "%1$s of %2$s used" : "%1$s/%2$s käytetty",
-    "Files settings" : "Tiedostojen asetukset",
-    "Show hidden files" : "Näytä piilotetut tiedostot",
-    "Crop image previews" : "Rajaa kuvien esikatseluja",
-    "WebDAV" : "WebDAV",
-    "Use this address to access your Files via WebDAV" : "Käytä tätä osoitetta yhdistääksesi tiedostosi WebDAV:in kautta",
-    "Toggle grid view" : "Ruudukkonäkymä päälle/pois",
-    "No files in here" : "Täällä ei ole tiedostoja",
-    "Upload some content or sync with your devices!" : "Lähetä tiedostoja tai synkronoi sisältö laitteidesi kanssa!",
-    "No entries found in this folder" : "Ei kohteita tässä kansiossa",
-    "Select all" : "Valitse kaikki",
-    "Upload too large" : "Lähetettävä tiedosto on liian suuri",
-    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Lähetettäväksi valitsemasi tiedostot ylittävät palvelimen salliman tiedostokoon rajan.",
-    "No favorites yet" : "Ei vielä suosikkeja",
-    "Files and folders you mark as favorite will show up here" : "Suosikeiksi merkitsemäsi tiedostot ja kansiot näkyvät täällä",
     "Deleted files" : "Poistetut tiedostot",
     "Shares" : "Jaot",
     "Shared with others" : "Jaettu muille",
@@ -215,13 +260,9 @@ OC.L10N.register(
     "Shared by link" : "Jaettu linkillä",
     "Deleted shares" : "Poistetut jaot",
     "Pending shares" : "Odottavat jaot",
-    "Text file" : "Tekstitiedosto",
-    "New text file.txt" : "Uusi tekstitiedosto.txt",
-    "Select" : "Valitse",
-    "You don’t have permission to upload or create files here" : "Käyttöoikeutesi eivät riitä tiedostojen lähettämiseen tai kansioiden luomiseen tähän sijaintiin",
-    "New" : "Uusi",
-    "Cannot transfer ownership of a file or folder you don't own" : "Et voi siirtää sellaisen tiedoston tai kansion omistajuutta, jota et itse omista",
-    "%s%% of %s used" : "%s%% / %s käytetty",
-    "Settings" : "Asetukset"
+    "Open folder {name}" : "Avaa kansio {name}",
+    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Tätä luetteloa ei ole esitetty täysin suorituskykyyn liittyvistä syistä. Tiedostot esitetään sitä mukaa, kun selaat luetteloa.",
+    "Search for an account" : "Etsi tiliä",
+    "No files or folders have been deleted yet" : "Tiedostoja tai kansioita ei ole vielä poistettu"
 },
 "nplurals=2; plural=(n != 1);");
