@@ -38,8 +38,8 @@ OC.L10N.register(
     "{actor} changed your email address" : "{actor} промени имейл адреса ви",
     "You changed your email address" : "Променихте имейл адреса си",
     "Your email address was changed by an administrator" : "Имейл адреса ви е променена от администратора",
-    "You created app password \"{token}\"" : "Създадохте парола за приложение „{token}“",
-    "An administrator created app password \"{token}\"" : "Администратор създаде парола за приложение „{token}“",
+    "You created an app password for a session named \"{token}\"" : "Създали сте парола за приложение за сесия с име „{token}“.",
+    "An administrator created an app password for a session named \"{token}\"" : "Администратор създаде парола за приложение за сесия с име „{token}“",
     "You deleted app password \"{token}\"" : "Изтрихте парола за приложение „{token}“",
     "You renamed app password \"{token}\" to \"{newToken}\"" : "Преименувахте паролата за приложение „{token}“ на „{newToken}“",
     "You granted filesystem access to app password \"{token}\"" : "Предоставихте достъп на файлова система до паролата за приложение „{token}“",
@@ -50,6 +50,7 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Отдалеченото изтриване беше стартирано на %1$s",
     "Remote wipe has finished on %1$s" : "Отдалеченото изтриване приключи на %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Вашата <strong>парола</strong> или <strong>имейл адрес</strong> е променен",
+    "Apps" : "Приложения",
     "Could not remove app." : "Приложението не можа да се премахне.",
     "Could not update app." : "Приложението не можа да се актуализира.",
     "Wrong password" : "Грешна парола",
@@ -70,9 +71,12 @@ OC.L10N.register(
     "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache е конфигуриран за премахване на кодови коментари. С активиран OPcache, <code>opcache.save_comments=1</code> трябва да бъде настроен за Nextcloud, за да функционира.",
     "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud няма право да използва OPcache API. При активиран OPcache е силно препоръчително да включите всички директории Nextcloud с <code>opcache.restrict_api</code> или деактивирайте тази настройка, за да деактивирате ограниченията на OPcache API, за да предотвратите грешки по време на надстройки на ядрото или приложението на Nextcloud.",
     "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud няма право да използва OPcache API. Силно препоръчително е да включите всички директории Nextcloud с <code>opcache.restrict_api</code> или деактивирайте тази настройка, за да деактивирате ограниченията на OPcache API, за да предотвратите грешки по време на надстройки на ядрото или приложението на Nextcloud.",
+    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply <code>opcache.file_cache_only=0</code> to your PHP configuration and use the file cache as second level cache only." : "Базираният на споделена памет OPcache е деактивиран. За по-добра производителност се препоръчва да приложите <code>opcache.file_cache_only=0</code> към конфигурацията на PHP и да използвате файловия кеш само като кеш от второ ниво.",
     "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Максималният брой OPcache ключове почти е надвишен. За да се гарантира, че всички скриптове могат да се задържат в кеш, се препоръчва да се приложи <code>opcache.max_accelerated_files</code> към вашата PHP конфигурация със стойност, по-висока от <code>%s</code>.",
     "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "Буферът на OPcache е почти пълен. За да се гарантира, че всички скриптове могат да се задържат в кеш, се препоръчва да се приложи <code>opcache.memory_consumption</code> към вашата PHP конфигурация със стойност, по-висока от <code>%s</code>.",
     "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "Буферът за интернирани низове в OPcache е почти пълен. За да се гарантира, че повтарящите се низове могат да бъдат ефективно кеширани, се препоръчва да се приложи <code>opcache.interned_strings_buffer</code> към вашата PHP конфигурация със стойност, по-висока от<code>%s</code>.",
+    "Administrator documentation" : "Документация за администратори",
+    "User documentation" : "Документация за потребители",
     "Invalid SMTP password." : "Невалидна SMTP парола.",
     "Email setting test" : "Тест за настройка на имейл",
     "Well done, %s!" : "Браво, %s!",
@@ -80,6 +84,7 @@ OC.L10N.register(
     "Email could not be sent. Check your mail server log" : "Ймеила не се изпрати.",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Възникна проблем при изпращането на имейла. Моля, провери настройките.  (Грешка: %s)",
     "You need to set your user email before being able to send test emails. Go to %s for that." : "Трябва да зададете свои потребителски имейл, преди да можете да изпращате тестови имейли. За това отидете на %s.",
+    "Users" : "Потребители",
     "Invalid user" : "Невалиден потребител",
     "Invalid mail address" : "невалиден адрес на електронна поща",
     "Settings saved" : "Настройките са запазени",
@@ -111,7 +116,6 @@ OC.L10N.register(
     "Go to %s" : "Отидете на %s",
     "Install Client" : "Инсталиране на клиента",
     "Logged in user must be a subadmin" : "Влезлият потребител трябва да е подадминистратор",
-    "Apps" : "Приложения",
     "Settings" : "Настройки",
     "Personal" : "Лични",
     "Administration" : "Административни",
@@ -122,6 +126,7 @@ OC.L10N.register(
     "Basic settings" : "Основни настройки",
     "Sharing" : "Споделяне",
     "Availability" : "Наличност",
+    "Calendar" : "Kалендар",
     "Personal info" : "Лични данни",
     "Mobile & desktop" : "Мобилни и настолни",
     "Email server" : "Имейл сървър",
@@ -169,7 +174,6 @@ OC.L10N.register(
     "View in store" : "Страница в магазина",
     "Visit website" : "Уеб страницата",
     "Report a bug" : "Докладване на грешка",
-    "User documentation" : "Документация за потребители",
     "Admin documentation" : "Документация за администратори",
     "Developer documentation" : "Документация за разработчици",
     "This app is supported via your current Nextcloud subscription." : "Това приложение се поддържа чрез текущия ви абонамент за Nextcloud.",
@@ -236,8 +240,7 @@ OC.L10N.register(
     "Webcron" : "Webcron",
     "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php е регистриран в услуга на webcron за извикване на cron.php на всеки 5 минути през HTTP. Случай на употреба: Много малък екземпляр (1–5 потребители в зависимост от употребата).",
     "Cron (Recommended)" : "Cron (препоръчително)",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "За да стартирате това, имате нужда от разширението PHP POSIX. Вижте {linkstart}документацията на PHP{linkend} за повече подробности.",
-    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Използвайте системна услуга cron, за да извиквате файла cron.php на всеки 5 минути. Препоръчва се за всички екземпляри.",
+    "Use system cron service to call the cron.php file every 5 minutes." : "Използвайте системната услуга cron, за да извикате файла cron.php на всеки 5 минути.",
     "The cron.php needs to be executed by the system user \"{user}\"." : "Cron.php трябва да се изпълни от системният потребител \"{user}\".",
     "Unable to update background job mode" : "Не може да се актуализира фонов режим на работа",
     "Profile" : "Профил",
@@ -264,11 +267,12 @@ OC.L10N.register(
     "Current password" : "Текуща парола",
     "New password" : "Нова парола",
     "Change password" : "Промени паролата",
+    "Your profile information" : "Информация за вашия профил",
     "Your profile picture" : "Вашата профилна снимка",
     "Upload profile picture" : "Качване на профилна снимка",
-    "Choose profile picture from files" : "Избор на профилна снимка от файлове",
+    "Choose profile picture from Files" : "Избор на профилна снимка от Файлове",
     "Remove profile picture" : "Премахване на профилна снимка",
-    "png or jpg, max. 20 MB" : "png или jpg, макс. 20 MB",
+    "The file must be a PNG or JPG" : "Файлът трябва да е във формат PNG или JPG",
     "Picture provided by original account" : "Снимката е предоставена от оригиналния профил",
     "Cancel" : "Отказ",
     "Set as profile picture" : "Задаване като профилна снимка",
@@ -301,6 +305,7 @@ OC.L10N.register(
     "Unable to delete additional email address" : "Не може да се изтрие допълнителен имейл адрес",
     "No email address set" : "Не е въведен имейл адрес",
     "Additional emails" : "Допълнителни имейли",
+    "Your handle" : "Вашият манипулатор",
     "Your headline" : "Вашето заглавие",
     "Language" : "Език",
     "Help translate" : "Помогнете с превода",
@@ -310,14 +315,12 @@ OC.L10N.register(
     "Week starts on {firstDayOfWeek}" : "Седмицата започва на {firstDayOfWeek}",
     "Unable to update locale" : "Не може да се актуализира езиково-географската променлива",
     "No locale set" : "Не е зададена езиково-географска променлива",
-    "Your location" : "Вашето местоположение",
     "Your organisation" : "Вашата организация",
     "Your phone number" : "Вашият тел. номер",
     "Edit your Profile visibility" : "Редактиране на видимостта на вашия профил",
     "Enable Profile" : "Активиране на профил",
     "Unable to update profile enabled state" : "Не може да се актуализира активирано състояние на профил",
     "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "По-рестриктивна настройка за видимост или обхват се спазва във вашия профил. Например, ако видимостта е зададена на „Показване на всички“ и обхватът е настроен на „Частен“, „Частен“ се зачита.",
-    "{displayId}" : "{displayId}",
     "Unable to update visibility of {displayId}" : "Не може да се актуализира видимостта на {displayId}",
     "Your role" : "Вашата роля",
     "Your Twitter handle" : "Вашият Twitter манипулатор",
@@ -329,12 +332,27 @@ OC.L10N.register(
     "Unable to update federation scope of additional {property}" : "Не може да се актуализира обхватът на обединяване на допълнителното {property}",
     "Add additional email" : "Добавяне на допълнителен имейл",
     "Add" : "Добави",
-    "You do not have permissions to see the details of this user" : "Нямате права да виждате подробности за този потребител",
+    "Default language" : "Стандартен език",
+    "Common languages" : "Познати езици",
+    "Other languages" : "Други езици",
+    "Password change is disabled because the master key is disabled" : "Промяната на паролата е деактивирана, защото главният ключ е деактивиран",
+    "New user" : "Нов потребител",
+    "Display name" : "Вписване като",
+    "Email" : "Имейл",
+    "Quota" : "Квота",
+    "Total rows summary" : "Обобщение на общия брой редове",
+    "Avatar" : "Аватар",
+    "Group admin for" : "Групов администратор за",
+    "User backend" : "Потребителски сървър",
+    "Storage location" : "Дисково пространство",
+    "Last login" : "Последно вписване",
     "Add new password" : "Въведете новата парола",
+    "You do not have permissions to see the details of this user" : "Нямате права да виждате подробности за този потребител",
     "Add new email address" : "Смени адреса на елетронната поща",
     "Add user to group" : "Добавяне на потребител към група",
     "Set user as admin for" : "Задаване на потребителя като администратор за",
     "Select user quota" : "Изберете потребителска квота",
+    "{size} used" : "{size} използвани",
     "Delete user" : "Изтриване",
     "Wipe all devices" : "Изтрии всички устройства",
     "Disable user" : "Деактивирай",
@@ -347,25 +365,15 @@ OC.L10N.register(
     "Account deletion" : "Изтриване на профил",
     "Delete {userid}'s account" : "Изтриване на профил на {userid}",
     "Welcome mail sent!" : "Изпратена е поща за добре дошли!",
-    "Edit User" : "Редактиране на потребител",
     "Toggle user actions menu" : "Превключване на менюто за действия на потребител",
-    "{size} used" : "{size} използвани",
-    "New user" : "Нов потребител",
-    "Will be autogenerated" : "Ще се генерира автоматично",
-    "Display name" : "Вписване като",
-    "Email" : "Имейл",
-    "Default language" : "Стандартен език",
-    "Add a new user" : "Добавяне на новия потребител",
-    "Group admin for" : "Групов администратор за",
-    "Quota" : "Квота",
-    "User backend" : "Потребителски сървър",
-    "Storage location" : "Дисково пространство",
-    "Last login" : "Последно вписване",
-    "No users in here" : "Тук няма потребители",
+    "Edit" : "Редактиране",
+    "Show user backend" : "Показване на потребителския сървър",
+    "Show storage path" : "Показване на пътя за хранилище",
+    "Show last login" : "Показвай последното вписване",
+    "Send email" : "Изпрати имейл",
+    "Defaults" : "Стойности по подразбиране",
     "Default quota" : "Стандартна квота",
-    "Common languages" : "Познати езици",
-    "Other languages" : "Други езици",
-    "Password change is disabled because the master key is disabled" : "Промяната на паролата е деактивирана, защото главният ключ е деактивиран",
+    "Select default quota" : "Изберете стандартна квота",
     "Passwordless authentication requires a secure connection." : "Удостоверяване без парола изисква сигурна връзка.",
     "Add WebAuthn device" : "Добавяне на WebAuthn устройство",
     "Please authorize your WebAuthn device." : "Моля, да упълномощите вашето WebAuthn устройство.",
@@ -380,11 +388,6 @@ OC.L10N.register(
     "The following devices are configured for your account:" : "Следните устройства са конфигурирани за вашия профил:",
     "Your browser does not support WebAuthn." : "Вашият браузър не поддържа WebAuthn.",
     "Your apps" : "Вашите приложения",
-    "Active apps" : "Включени приложения",
-    "Disabled apps" : "Изключени приложения",
-    "Updates" : "Актуализации",
-    "App bundles" : "Пакети с приложения",
-    "Featured apps" : "Представени приложения",
     "{license}-licensed" : "{license}-лицензиран",
     "Changelog" : "Списък на промените",
     "by {author}\n{license}" : "от {author}\n{license}",
@@ -393,13 +396,6 @@ OC.L10N.register(
     "Active users" : "Активни потребители",
     "Admins" : "Администратори",
     "Disabled users" : "Деактивирани потребители",
-    "Default quota:" : "Стандартна квота:",
-    "Select default quota" : "Изберете стандартна квота",
-    "Show Languages" : "Показвай ползвания език",
-    "Show last login" : "Показвай последното вписване",
-    "Show user backend" : "Показване на потребителския сървър",
-    "Show storage path" : "Показване на пътя за хранилище",
-    "Send email to new user" : "Изпращай писмо към нов потребител",
     "Not saved" : "Не е запазено",
     "Sending…" : "Изпращане...",
     "Email sent" : "Имейлът е изпратен",
@@ -413,11 +409,17 @@ OC.L10N.register(
     "Phone number" : "Тел. номер",
     "Role" : "Роля",
     "Twitter" : "Twitter",
+    "Fediverse (e.g. Mastodon)" : "Fediverse (напр. Mastodon)",
     "Website" : "Уеб страница",
     "Profile visibility" : "Видимост на профил",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Не е налично, тъй като това свойство е нужно за основна функционалност, включително споделяне на файлове и покани в календар",
     "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Не е налично, тъй като федерирането е деактивирано за вашия профил, свържете се с вашия системен администратор, ако имате въпроси.",
     "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Не е налично, тъй като публикуването на специфични потребителски данни на сървъра за търсене не е разрешено, свържете се с вашия системен администратор, ако имате въпроси",
+    "Active apps" : "Включени приложения",
+    "Disabled apps" : "Изключени приложения",
+    "Updates" : "Актуализации",
+    "App bundles" : "Пакети с приложения",
+    "Featured apps" : "Представени приложения",
     "Show to everyone" : "Показване на всички",
     "Show to logged in users only" : "Показване само на влезли потребители",
     "Hide" : "Скриване",
@@ -429,30 +431,26 @@ OC.L10N.register(
     "An error occurred during the request. Unable to proceed." : "Възникна грешка по време на заявката. Не може да се продължи.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Приложението е активирано, но трябва да бъде актуализирано. Ще бъдете пренасочени към страницата за актуализация след 5 секунди.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Грешка: Това приложение не може да бъде активирано, защото прави сървъра нестабилен",
-    "Administrator documentation" : "Документация за администратори",
+    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Имаше твърде много заявки от вашата мрежа. Опитайте отново по-късно или се свържете с вашия администратор, ако това е грешка.",
     "Documentation" : "Документация",
     "Forum" : "Форум",
     "Login" : "Вписване",
-    "Plain" : "Обикновен",
-    "NT LAN Manager" : "NT LAN Manager",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
+    "SSL" : "SSL",
     "Open documentation" : "Отвори документацията",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "След като настроите сървъра Nextcloud ще може да изпраща имейли за възстановяване на забравени пароли и известия.",
     "Send mode" : "Режим на изпращане",
     "Encryption" : "Криптиране",
     "Sendmail mode" : "Режим на изпращане на поща",
     "From address" : "От адрес",
-    "Authentication method" : "Метод за удостоверяване",
-    "Authentication required" : "Нужно е удостоверяване",
     "Server address" : "Адрес на сървъра",
     "Port" : "Порт",
+    "Authentication" : "Удостоверяване",
+    "Authentication required" : "Нужно е удостоверяване",
     "Credentials" : "Потребител и парола",
     "SMTP Username" : "SMTP потребител",
     "SMTP Password" : "SMTP парола",
     "Save" : "Запазване",
     "Test and verify email settings" : "Тествайте и потвърждаване на настройките на имейла",
-    "Send email" : "Изпрати имейл",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Важно е, от гледна точка на сигурност и производителност, всичко да бъде настроено коректно. За тази цел са създадени автоматични проверки. Прегледайте връзките, към документацията (по-долу), за допълнителна информация.",
     "All checks passed." : "Всички проверки са преминати.",
     "There are some errors regarding your setup." : "Открити са грешки, в инсталацията на Nextcloud.",
@@ -481,8 +479,6 @@ OC.L10N.register(
     "Restrict users to only share with users in their groups" : "Ограничи потребителите, така че да могат да споделят само с други потребители в своите групи.",
     "Exclude groups from sharing" : "Забрани групи да споделят",
     "These groups will still be able to receive shares, but not to initiate them." : "Тези групи ще могат да получават споделения, но няма да могат самите те да споделят.",
-    "Allow username autocompletion in share dialog" : "Разрешаване на автоматично довършване на име на потребител в диалоговия прозорец за споделяне",
-    "Allow username autocompletion to users within the same groups" : "Разрешаване на автоматично довършване на име на потребител на потребители в същите групи",
     "Allow username autocompletion to users based on phone number integration" : "Разрешаване на автоматично довършване на име на потребител на потребители въз основа на интегриране на телефонен номер",
     "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Ако автоматичното довършване „същата група“ и „интегриране на телефонен номер“ са активирани, съвпадението в едното е достатъчно, за да се покаже на потребителя.",
     "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Разрешаване на автоматично довършване при въвеждане на пълното име или имейл адрес (като игнорирате липсващото съвпадение в телефонния указател и сте в същата група)",
@@ -499,70 +495,26 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Тази общностна версия на Nextcloud не се поддържа и не са налични незабавни известия.",
     "Use a second factor besides your password to increase security for your account." : "Ползвайте двустепенно удостоверяване за да повишите сигурността на профила си.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Ако използвате приложения на трети страни, за да се свържете с Nextcloud, моля, не забравяйте да създадете и конфигурирате парола за приложение за всяко едно от тях, преди да активирате удостоверяване на втория фактор.",
-    "Migration in progress. Please wait until the migration is finished" : "В ход е миграция. Моля, изчакайте, докато миграцията приключи",
-    "Migration started …" : "Миграцията започна …",
-    "An error occurred while changing your language. Please reload the page and try again." : "Възникна грешка при опита за промяна на езика. Моля рестартирайте страницата и опитайте отново",
-    "An error occurred while changing your locale. Please reload the page and try again." : "Възникна грешка при опита за промяна на езикова променлива. Моля рестартирайте страницата и опитайте отново",
-    "Select a profile picture" : "Избор на снимка за профила",
-    "Week starts on {fdow}" : "Първи ден от седмицата е {fdow}",
-    "Couldn't remove app." : "Приложението не бе премахнато.",
-    "Couldn't update app." : "Приложението не бе актуализирано.",
-    "Backend doesn't support password change, but the user's encryption key was updated." : "Сървърът не поддържа промяна на паролата, но ключът за криптиране на потребителя е актуализиран.",
-    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Не можа да се определи дали TLS версията на cURL е остаряла или не, защото възникна грешка по време на HTTPS заявката срещу https://nextcloud.com. Моля, проверете регистрационния файл на nextcloud за повече подробности.",
-    "You need to set your user email before being able to send test emails." : "Трябва да зададете своя имейл за да можете да изпращате тестови имейли.",
-    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Отмяната на този маркер може да попречи на изтриването на вашето устройство, ако то все още не е започнало изтриването.",
-    "Set as primary mail" : "Задаване като основна поща",
-    "Change privacy level of email" : "Промяна на нивото на поверителност на имейла",
-    "All languages" : "Всички езици",
-    "Everyone" : "Всички",
-    "An error occured during the request. Unable to proceed." : "Възникна грешка по време на заявката. Не може да се продължи.",
-    "Test email settings" : "Проверка на имейл настройките",
-    "Please read carefully before activating server-side encryption: " : "Моля, прочетете внимателно, преди да активирате криптирането от страна на сървъра:",
-    "Enable encryption" : "Включване на криптиране",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Трябва да мигрирате ключовете си за криптиране от старото криптиране (ownCloud <= 8.0) към новото. Моля, активирайте „Модул за криптиране по подразбиране“ и изпълнете „occ encryption:migrate“",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Трябва да мигрирате ключовете си за криптиране от старото криптиране (ownCloud <= 8.0) към новото.",
-    "Start migration" : "Начало на миграцията",
-    "Last job execution ran %s. Something seems wrong." : "За последно cron задача е стартирала %s. Изглежда, че има проблем.",
-    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Някои задачи не са били изпълнени от %s. Моля, помислете за увеличаване на честотата на изпълнение.",
-    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Някои задачи не са изпълнени след %s. Моля, помислете за преминаване към система cron.",
-    "Last job ran %s." : "За последно cron задача е стартирала %s.",
-    "Background job didn’t run yet!" : "Фоновата задача все още не е стартирана!",
-    "For the server to work properly, it's important to configure background jobs correctly. \"Cron\" is the recommended setting. Please see the documentation for more information." : "За да работи правилно сървърът, е важно да конфигурирате правилно фоновите задачи. Препоръчителната настройка е Cron. Моля, вижте документацията за повече информация.",
-    "Pick background job setting" : "Изберете настройка за фонова работа",
-    "Recommended" : "Препоръчано",
-    "The cron.php needs to be executed by the system user \"%s\"." : "Необходимо е cron.php да се стартира от системния потребител \"%s\".",
-    "days" : "дена",
-    "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Разрешаване на автоматично довършване на име на потребител при въвеждане на пълното име или имейл адрес (като игнорирате липсващото съвпадение в телефонния указател и сте в същата група)",
-    "Change privacy level of profile picture" : "Промяна на нивото на поверителност на снимката на потребителския профил",
-    "Upload new" : "Качи нова",
-    "Select from Files" : "Избери от файловете",
-    "Remove image" : "Премахни изображението",
-    "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Моля, имайте предвид, че може да отнеме до 24 часа, докато аватарът се актуализира навсякъде.",
-    "Choose as profile picture" : "Избор на профилна снимка",
-    "You are using <strong>%s</strong>" : "Ползвате <strong>%s</strong>",
-    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Вие използвате <strong>%1$s</strong> от <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
-    "Change privacy level of full name" : "Промяна на нивото на поверителност на пълното име",
-    "No display name set" : "Няма настроено екранно име",
-    "Change privacy level of phone number" : "Промяна на нивото на поверителност на телефонния номер",
-    "Address" : "Адрес",
-    "Change privacy level of address" : "Промяна на нивото на поверителност на адреса",
-    "Your postal address" : "Вашият пощенски код",
-    "Change privacy level of website" : "Промяна на нивото на поверителност на уеб сайт",
-    "It can take up to 24 hours before the account is displayed as verified." : "Може да отнеме до 24 часа, преди профилът да се покаже като потвърден.",
-    "Link https://…" : "Връзка https://…",
-    "Change privacy level of Twitter profile" : "Промяна на нивото на поверителност на профила в Twitter",
-    "Twitter handle @…" : "Twitter манипулатор @…",
-    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Максималният брой OPcache ключове почти е надвишен. За да се гарантира, че всички скриптове могат да се задържат в кеш, се препоръчва да се приложи <code>opcache.max_accelerated_files</code> към вашата PHP конфигурация със стойност, по-висока от <code>%s</code>.",
-    "Admin privileges" : "Администраторски привилегии",
-    "Unable to update biography" : "Биографията не може да се актуализира ",
-    "Unable to update full name" : " Пълното име не може да се актуализира",
-    "No full name set" : "Няма зададено пълно име",
-    "Unable to update headline" : "Заглавието не може да се актуализира",
-    "Unable to update organisation" : "Организацията не може да се актуализира",
-    "Unable to update role" : "Ролята не може да се актуализира",
-    "Change scope level of {accountProperty}" : "Промяна на нивото на обхвата на {accountProperty}",
-    "Unable to update federation scope of the primary {accountProperty}" : "Не може да се актуализира обхвата на федерация на основния {accountProperty}",
-    "Unable to update federation scope of additional {accountProperty}" : "Не може да се актуализира обхвата на федерация на допълнителен {accountProperty}",
-    "Avatar" : "Аватар"
+    "You created app password \"{token}\"" : "Създадохте парола за приложение „{token}“",
+    "An administrator created app password \"{token}\"" : "Администратор създаде парола за приложение „{token}“",
+    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "За да стартирате това, имате нужда от разширението PHP POSIX. Вижте {linkstart}документацията на PHP{linkend} за повече подробности.",
+    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Използвайте системна услуга cron, за да извиквате файла cron.php на всеки 5 минути. Препоръчва се за всички екземпляри.",
+    "Choose profile picture from files" : "Избор на профилна снимка от файлове",
+    "png or jpg, max. 20 MB" : "png или jpg, макс. 20 MB",
+    "Your location" : "Вашето местоположение",
+    "Edit User" : "Редактиране на потребител",
+    "Will be autogenerated" : "Ще се генерира автоматично",
+    "Add a new user" : "Добавяне на новия потребител",
+    "No users in here" : "Тук няма потребители",
+    "Default quota:" : "Стандартна квота:",
+    "Show Languages" : "Показвай ползвания език",
+    "Send email to new user" : "Изпращай писмо към нов потребител",
+    "Plain" : "Обикновен",
+    "NT LAN Manager" : "NT LAN Manager",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "Authentication method" : "Метод за удостоверяване",
+    "Allow username autocompletion in share dialog" : "Разрешаване на автоматично довършване на име на потребител в диалоговия прозорец за споделяне",
+    "Allow username autocompletion to users within the same groups" : "Разрешаване на автоматично довършване на име на потребител на потребители в същите групи"
 },
 "nplurals=2; plural=(n != 1);");
