@@ -2,6 +2,7 @@ OC.L10N.register(
     "text",
     {
     "New text file" : "Нова текстуална датотека",
+    "Create new text file" : "Креирај нова текстуална датотека",
     "The file was uploaded" : "Датотеката е прикачена",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Подигнатата датотека ја надминува upload_max_filesize директивата во php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Големината на датотеката ја надминува MAX_FILE_SIZE директивата која е одредена во HTML формата",
@@ -13,8 +14,10 @@ OC.L10N.register(
     "No file uploaded or file size exceeds maximum of %s" : "Нема прикачена дадотека или големината го надмминува максимумот од %s",
     "Nextcloud Text" : "Текст",
     "text document" : "текстуален документ",
+    "{user} has mentioned you in the text document {node}" : "{user} те спомна во текстуална датотека {node}",
     "Readme" : "Прочитај",
     "Text" : "Текст",
+    "📝 Collaborative document editing" : "📝 Колаборативно уредување на документи",
     "Use current version" : "Користи ја моменталната верзија",
     "Use the saved version" : "Користи ја зачуваната верзија",
     "Document idle for {timeout} minutes, click to continue editing" : "Документот е неактивен {timeout} минути, кликни за да продолжиш со уредување",
@@ -22,31 +25,36 @@ OC.L10N.register(
     "The document has been changed outside of the editor. The changes cannot be applied." : "Документот не е изменет од уредникот. Промените не можат да се применат.",
     "File could not be loaded. Please check your internet connection." : "Датотеката неможе да се вчита. Проверете ја вашата интернет врска.",
     "This file is opened read-only as it is currently locked by {user}." : "Оваа датотека е отворена како за читање и истата е заклучена од {user}.",
+    "Close outline view" : "Затвори преглед",
+    "Outline" : "Преглед",
     "Enter your name so other people can see who is editing" : "Напишете го вашето име за да можат другите корисници да знаат кој уредува",
     "Edit guest name" : "Промени име на гостин",
     "Guest" : "Гостин",
     "Save guest name" : "Зачувај име на гостин",
+    "Insert an attachment" : "Вметни прилог",
     "guest" : "гостин",
+    "Show author colors" : "Прикажи ги боите на авторот",
+    "Author colors are only shown until everyone has closed the document." : "Боите на авторот се прикажуваат само кога сите ќе го затворат документот.",
     "Active people" : "Активни луѓе",
-    "Document save status" : "Статус на зачувување на документот",
+    "Save document" : "Зачувај документ",
     "Last saved" : "Последно зачувано",
+    "Offline" : "Исклучен",
     "Saving …" : "Зачувува ...",
     "Saved" : "Зачувано",
-    "Last saved {lastSaved}" : "Последно зачувано {lastSaved}",
+    "Last saved {lastSave}" : "Последно зачувано {lastSave}",
     "Unsaved changes" : "Незачувани промени",
-    "No emoji found" : "Не се пронајдени емотикони",
     "Formatting help" : "Помош за форматирање",
     "Speed up your writing with simple shortcuts." : "Забрзајте го вашето пишување со овие едноставни кратенки.",
     "Style" : "Стил",
     "Syntax" : "Синтакса",
     "Keyboard shortcuts" : "Кратенки преку тастатура",
+    "Shift" : "Shift",
     "Bold" : "Болд",
     "Bold text" : "Болдиран текст",
     "Ctrl" : "Ctrl",
     "Italic" : "Италик",
     "Strikethrough" : "Прецртај",
     "Mistaken text" : "Погрешен текст",
-    "Shift" : "Shift",
     "Underline" : "Подвлечен",
     "Underlined text" : "Подвлечен текст",
     "Heading 1" : "Заглавие 1",
@@ -57,7 +65,14 @@ OC.L10N.register(
     "Some code" : "Некој код",
     "Upload from computer" : "Прикачи од компјутер",
     "Insert from Files" : "Вметни од датотеките",
+    "Select file or folder to link to" : "Изберете датотека или папка за линк до",
     "Editor actions" : "Акции на уредникот",
+    "Translate" : "Преведи",
+    "Select language" : "Изберете јазик",
+    "to" : "до",
+    "Replace" : "Преклопи",
+    "No emoji found" : "Не се пронајдени емотикони",
+    "Source code" : "Изворен код",
     "Failed to load" : "Неуспешно вчитување",
     "Unsupported image type" : "Неподржан вид на слика",
     "Add row before" : "Додади ред пред",
@@ -67,7 +82,7 @@ OC.L10N.register(
     "Add column after" : "Додади колона после",
     "Delete this column" : "Избриши ја оваа колона",
     "Delete this table" : "Избриши ја оваа табела",
-    "Add notes, lists or links …" : "Додади белешки, листи или линкови ...",
+    "Show rich workspaces" : "Прикажи збогатен работен простор",
     "Undo" : "Назад",
     "Redo" : "Напред",
     "Headings" : "Заглавија",
@@ -83,19 +98,14 @@ OC.L10N.register(
     "Command" : "Команда",
     "Control" : "Контрола",
     "Option" : "Опции",
+    "Add notes, lists or links …" : "Додади белешки, листи или линкови ...",
     "Edit" : "Уреди",
-    "New text document" : "Нов текстуален документ",
-    "Enter your name so other users can see who is editing" : "Напишете го вашето име за да можат другите корисници да знаат кој уредува",
-    "Insert image" : "Вметни фотографија",
-    "Insert an image" : "Вметни фотографија",
+    "Add description" : "Додади опис",
+    "Document save status" : "Статус на зачувување на документот",
     "Update Link" : "Ажурирај линк",
     "Add Link" : "Додади линк",
     "Link file" : "Поврзи датотека (Линк)",
-    "Select file to link to" : "Изберете датотека за линк до неа",
-    "Currently active users:" : "Моментално активни корисници:",
-    "_and %n other editor_::_and %n other editors_" : ["и 1 друг уредник","и%n други уредници"],
-    "Image file format not supported" : "Форматот на датотеката со слика не е поддржан",
-    "Alt" : "Alt",
-    "Remove Link" : "Острани линк"
+    "Remove Link" : "Острани линк",
+    "Select file to link to" : "Изберете датотека за линк до неа"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
