@@ -38,7 +38,6 @@ OC.L10N.register(
     "Learn more ↗" : "بیشتر بدانید ↗",
     "Preparing update" : "آماده‌سازی به روز‌ رسانی",
     "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Please use the command line updater because automatic updating is disabled in the config.php." : "Please use the command line updater because automatic updating is disabled in the config.php.",
     "Turned on maintenance mode" : "حالت \" در دست تعمیر \" فعال شد .",
     "Turned off maintenance mode" : "حالت \" در دست تعمیر \" غیرفعال شد .",
     "Maintenance mode is kept active" : "حالت تعمیرات فعال نگه‌داشته شده است",
@@ -91,8 +90,9 @@ OC.L10N.register(
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "برنامه ایمیل ساده با پرونده ها ، مخاطبین و تقویم یکپارچه شده است.",
     "Forgot password?" : "رمز فراموش شده؟",
     "Back" : "بازگشت",
+    "Load more results" : "بار کردن نتیحه‌های بیش‌تر",
     "Search" : "جست‌و‌جو",
-    "Settings" : "تنظیمات",
+    "Settings menu" : "فهرست تنظیمات",
     "Search contacts …" : "جستجو مخاطبین ...",
     "No contacts found" : "مخاطبین یافت نشد",
     "Show all contacts …" : "نمایش همه مخاطبین ...",
@@ -127,9 +127,13 @@ OC.L10N.register(
     "(all selected)" : "(همه انتخاب شده اند)",
     "({count} selected)" : "({count} انتخاب شده)",
     "Error loading file exists template" : "خطا در بارگزاری فایل قالب",
+    "Show list view" : "نمایش فهرستی",
+    "Show grid view" : "نمایش شبکه‌ای",
     "Pending" : "در انتظار",
+    "Home" : "خانه ",
     "Copy to {folder}" : "کپی به {folder}",
     "Move to {folder}" : "انتقال به {folder}",
+    "Saving …" : "ذخیره کردن …",
     "Authentication required" : "احراز هویت مورد نیاز است",
     "This action requires you to confirm your password" : "این اقدام نیاز به تایید رمز عبور شما دارد",
     "Confirm" : "تایید",
@@ -138,6 +142,8 @@ OC.L10N.register(
     "Connection to server lost" : "اتصال به سرور از دست رفته است",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["%nمشکل بارگذاری صفحه، بارگیری مجدد در  ثانیه","%nمشکل بارگذاری صفحه، بارگیری مجدد در  ثانیه"],
     "Hide details" : "مخفی کردن جزئیات",
+    "New in" : "جدید در",
+    "View changelog" : "مشاهده تغییرات",
     "Very weak password" : "رمز عبور بسیار ضعیف",
     "Weak password" : "رمز عبور ضعیف",
     "So-so password" : "رمز عبور متوسط",
@@ -195,15 +201,13 @@ OC.L10N.register(
     "Install" : "نصب",
     "Need help?" : "کمک لازم دارید ؟",
     "See the documentation" : "مشاهده‌ی مستندات",
-    "Contacts" : "مخاطبین",
-    "Contacts menu" : "منوی دفتر تلفن",
+    "Go to %s" : "برو به %s",
     "Confirm your password" : "گذرواژه خود را تأیید کنید",
     "App token" : "App token",
     "Grant access" : " مجوز اعطا دسترسی",
     "Account access" : "دسترسی به حساب",
     "This share is password-protected" : "این اشتراک توسط رمز عبور محافظت می شود",
     "Email address" : "آدرس ایمیل",
-    "Go to %s" : "برو به %s",
     "Use backup code" : "از کد پشتیبان استفاده شود",
     "App update required" : "نیاز به بروزرسانی برنامه وجود دارد",
     "These incompatible apps will be disabled:" : "این برنامه های ناسازگار غیر فعال می شوند:",
@@ -213,11 +217,8 @@ OC.L10N.register(
     "Detailed logs" : "Detailed logs",
     "Update needed" : "نیاز به روز رسانی دارد",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "اگر این پیغام همچنان وجود داشت یا به صورت غیر منتظره ظاهر شد با مدیر سیستم تماس بگیرید.",
-    "[%d / %d]: Checking table %s" : "[%d / %d]: چک کردن جدول %s",
-    "restricted" : "محدود",
-    "invisible" : "غیر قابل مشاهده",
+    "Settings" : "تنظیمات",
     "File not found" : "فایل یافت نشد",
-    "More" : "بیش‌تر",
-    "The password is wrong. Try again." : "رمزعبور اشتباه می باشد. دوباره امتحان کنید."
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Please use the command line updater because automatic updating is disabled in the config.php."
 },
 "nplurals=2; plural=(n > 1);");
