@@ -46,7 +46,6 @@ OC.L10N.register(
     "Repair info:" : "Инфо при поправка:",
     "Repair warning:" : "Предупредувања при поправка:",
     "Repair error:" : "Грешка при поправка:",
-    "Please use the command line updater because automatic updating is disabled in the config.php." : "Ве молиме користете ја командната линија за ажурирање бидејќи автоматското ажурирање е оневозможено во config.php.",
     "Turned on maintenance mode" : "Вклучен е модот за одржување",
     "Turned off maintenance mode" : "Ислкучен е модот за одржување",
     "Maintenance mode is kept active" : "Модот за одржување е уште активен",
@@ -76,7 +75,7 @@ OC.L10N.register(
     "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Овој опслужувач нема работна Интернет врска. Ова значи дека некои опции како што е монтирање на надворешни складишта, известувања за ажурирање или инсталации на апликации од 3-ти лица нема да работат. Пристапот на датотеки од далечина и праќање на пораки за известувања може исто така да не работат. Ви советуваме да овозможите Интернет врска за овој опслужувач ако сакате да ги имате сите опции. ",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Не е конфигурирана мемориjа за кеширање. За да ги подобрите перформансите, конфигурирајте memcache, доколку е можно. Дополнителни информации може да се најдат во {linkstart}документацијата{linkend}.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Моненталната верзија на PHP е {version}. Ажурирајте ја PHP верзијата да ги искористите предностите од {linkstart}перформанси и безбедносни ажурирања обезбедени од групацијата PHP ↗{linkend} штом вашата дистрибуција го поддржува.",
-    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 е последна верзија која поддржува PHP 7.3. За Nextcloud 24 потребна е PHP 7.4",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Некои датотеки не ја поминаа проверката на интегритет. Дополнителни информации за тоа како да се реши ова прашање може да се најде во  {linkstart1}документацијата↗{linkend}. ({linkstart2}Листа на невалидни датотеки…{linkend} / {linkstart3}Повторно скенирање…{linkend})",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP функцијата \"set_time_limit\" не е достапна. Ова може да резултира со запирање на скриптите во извршувањето, и грешки во вашата инсталација. Овозможувањето на оваа функција е препорачлива.",
     "Missing index \"{indexName}\" in table \"{tableName}\"." : "Недостасува индексот \"{indexName}\" во табелата \"{tableName}\".",
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Во базата недостасуваат некој индекси. Поради фактот што додавањето индекси во големи бази може да потрае, тие не беа додадени автоматски. Со стартување на командата \"occ db:add-missing-indices\" ќе бидат додадени оние индекси што недостасуваат и инстанцата непречено ќе работи. Еднаш кога ќе бидат додадени индексите, барањата во табелите ќе биде многу побрзо.",
@@ -98,9 +97,9 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Вашата папка за податоци и вашите датотеки се најверојатно достапни од интернет. Датотеката .htaccess не работи. Строго ви препорачуваме да го подесите вашиот веб опслужувач на начин на кој вашата папка за податоци не е веќе достапна од интернет или да ја преместите папката за податоци надвор од коренот на веб опслужувачот.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавието \"{header}\" не е поставено да биде \"{expected}\". Ова потенцијално може да ја загрози приватноста и безбедноста, се препорачува соодветно да ја поставите оваа поставка.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP заглавието \"{header}\" не е поставено да биде \"{expected}\". Некои карактеристики може да не функционираат правилно, се препорачува соодветно да ја поставите оваа поставка.",
+    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавието \"{header}\" не го содржи \"{expected}\". Ова потенцијално може да ја загрози приватноста и безбедноста, се препорачува соодветно да ја поставите оваа поставка.",
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "HTTP заглавието \"{header}\" не е поставено да биде \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" или \"{val5}\". Ова може да открие сигурносни информации. Погледнете {linkstart}Препораки за W3C ↗{linkend}.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "\"Strict-Transport-Security\" HTTP насловот не е поставен на мнајмалку \"{seconds}\" секунди. За подобрена безбедност, се препорачува да се овозможи HSTS како што е опишано во {linkstart}совети за безбедност ↗{linkend}.",
-    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "Пристапувате до станата преку HTTP. Препорачуваме да го поставите вашиот сервер за да се пристапува преку HTTPS, проверете како е опишано во {linkstart}безбедносни совети ↗{linkend}.",
     "unknown text" : "непознат текст",
     "Hello world!" : "Здраво свету!",
     "sunny" : "сончево",
@@ -118,6 +117,7 @@ OC.L10N.register(
     "Continue to {productName}" : "Продолжи кон {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Ажурирањето беше успешно. Пренасочување кон {productName} за 1 секунда.","Ажурирањето беше успешно. Пренасочување кон {productName} за %n секунди."],
     "More apps" : "Повеќе апликации",
+    "Currently open" : "Моментално отворено",
     "_{count} notification_::_{count} notifications_" : ["Едно исзестување","{count} известувања"],
     "Log in" : "Најава",
     "Logging in …" : "Најава ...",
@@ -125,12 +125,13 @@ OC.L10N.register(
     "Please contact your administrator." : "Ве молиме контактирајте го вашиот администратор.",
     "An internal error occurred." : "Се случи внатрешна грешка.",
     "Please try again or contact your administrator." : "Ве молиме обидете се повторно или контактирајте го вашиот администратор.",
-    "Log in to {productName}" : "Најави се на {productName}",
     "Account name or email" : "Корисничко име или е-пошта",
     "Password" : "Лозинка",
+    "Log in to {productName}" : "Најави се на {productName}",
     "Wrong username or password." : "Погрешно корисничко име или лозинка.",
     "User disabled" : "Корисникот е оневозможен",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Детектирани се повеќе неуспешни најавувања од вашата IP адреса. Затоа вашиот следен обид за најавување е одложено за 30 секунди.",
+    "Log in with a device" : "Најавете се со уред",
     "Username or email" : "Корисничко име или е-пошта",
     "Your account is not setup for passwordless login." : "Вашата сметка не е поставена за најавување без лозинка.",
     "Browser not supported" : "Вашиот прелистувач не е поддржан",
@@ -138,8 +139,6 @@ OC.L10N.register(
     "Your connection is not secure" : "Конекцијата не е безбедна",
     "Passwordless authentication is only available over a secure connection." : "Автентикација без лозинка е достапно доколку користите безбедна конекција.",
     "Reset password" : "Ресетирај лозинка",
-    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Порака за ресетирање на лозинката е испратена на е-пошта на оваа сметка. Доколку не сте ја добиле, проверете во spam/junk папката или прашајте го вашиот локален администратор за помош.",
-    "If it is not there ask your local administrator." : "Доколку не е таму, прашајте го вашиот локален администратор.",
     "Couldn't send reset email. Please contact your administrator." : "Не можам да истпратам порака за ресетирање. Ве молам контактирајте го вашиот администратор.",
     "Password cannot be changed. Please contact your administrator." : "Лозинката не може да се промени. Ве молам контактирајте го вашиот администратор.",
     "Back to login" : "Врати се на страната за најавување",
@@ -160,8 +159,8 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "Чувајте ги вашите колеги и пријатели на едно место без да ги разоткривате нивните приватни информации.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Едноставна апликација за е-пошта интегрирана со Датотеки, Контакти, Календар.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Разговори, видео повици, споделување на екранот, онлајн состаноци и веб конференции - на вашиот компјутер и на вашиот мобилен телефон.",
+    "Search contacts" : "Пребарување контакти",
     "Forgot password?" : "Заборавена лозинка?",
-    "Log in with a device" : "Најавете се со уред",
     "Back" : "Назад",
     "Login form is disabled." : "Формата за најава е оневозможена.",
     "Edit Profile" : "Уреди профил",
@@ -171,16 +170,21 @@ OC.L10N.register(
     "Reset search" : "Ресетирај пребарување",
     "Start search" : "Започни пребарување",
     "Search for {name} only" : "Пребарај само за {name}",
-    "No results for {query}" : "Нема резултати за {query}",
-    "Press enter to start searching" : "Притисни Enter за започне пребарувањето",
     "Start typing to search" : "Напишете нешто за пребарување",
     "Loading more results …" : "Вчитување на повеќе резултати ...",
     "Load more results" : "Вчитај повеќе резултати",
     "Search" : "Барај",
+    "No results for {query}" : "Нема резултати за {query}",
     "An error occurred while searching for {type}" : "Настана грешка при пребарување за {type}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Внесете најмалку {minSearchLength} карактер за да пребарувате","Внесете најмалку {minSearchLength} карактери или повеќе за да пребарувате"],
+    "This browser is not supported" : "Овој прелистувач не е поддржан",
+    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Вашиот прелистувач не е поддржан. Надградете на понова или поддржана верзија.",
+    "Continue with this unsupported browser" : "Продолжете со овој неподдржан прелистувач",
+    "Supported versions" : "Поддржани верзии",
+    "{name} version {version} and above" : "{name} верзија {version} и понови",
+    "Open settings menu" : "Мени за параметри",
+    "Settings menu" : "Мени за параметри",
     "Search {types} …" : "Пребарување {types} …",
-    "Settings" : "Параметри",
     "Could not load your contacts" : "Неможат да се вчитаат вашите контакти",
     "Search contacts …" : "Пребарување контакти ...",
     "No contacts found" : "Не се пронајдени контакти",
@@ -222,6 +226,7 @@ OC.L10N.register(
     "Show list view" : "Прикажи поглед во листа",
     "Show grid view" : "Прикажи поглед во мрежа",
     "Pending" : "Чекање",
+    "Home" : "Дома",
     "Copy to {folder}" : "Копирај во {folder}",
     "Move to {folder}" : "Премести во {folder}",
     "Saving …" : "Зачувува ...",
@@ -317,10 +322,7 @@ OC.L10N.register(
     "Skip to main content" : "Оди до главната содржина",
     "Skip to navigation of app" : "Оди до навигацијата на апликацијата",
     "Get your own free account" : "Креирајте ваша сметка",
-    "%s's homepage" : "Страната на %s",
-    "Contacts" : "Контакти",
-    "Contacts menu" : "Мени за контакти",
-    "Open settings menu" : "Мени за параметри",
+    "Go to %s" : "Оди до %s",
     "Confirm your password" : "Потврдете ја вашата лозинка",
     "Connect to your account" : "Поврзани со вашата сметка",
     "Please log in before granting %1$s access to your %2$s account." : "Ве молиме најавете се пред да доделите пристап на %1$s во вашата %2$s сметка.",
@@ -329,7 +331,7 @@ OC.L10N.register(
     "Grant access" : "Дозволи пристап",
     "Alternative log in using app token" : "Алтернативен начин на најава со користење на токен",
     "Account access" : "Пристап до сметка",
-    "Currently logged in as %1$s (%2$s)." : "Моментално најавени сте како %1$s (%2$s).",
+    "Currently logged in as %1$s (%2$s)." : "Најавени сте како %1$s (%2$s).",
     "You are about to grant %1$s access to your %2$s account." : "Ќе доделите пристап на %1$s во вашата %2$s сметка.",
     "Account connected" : "Сметката е поврзана",
     "Your client should now be connected!" : "Вашиот клиент сега треба да биде поврзан!",
@@ -340,7 +342,6 @@ OC.L10N.register(
     "Email address" : "Е-пошта адреси",
     "Password sent!" : "Лозинка е испратена!",
     "You are not authorized to request a password for this share" : "Не сте авторизиран за да побарате лозинка за ова споделување",
-    "Go to %s" : "Оди до %s",
     "Two-factor authentication" : "Двофакторна автентикација",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Подобрете ја сигурноста на вашата сметка. Изберете двофакторна автентификација:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Неможе да се вчита овозможениот начини за дво-факторна автентификација. Ве молиме контактирајте го администраторот.",
@@ -373,25 +374,13 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Истанцата %s моментално е во режим на одржување, што значи дека може да потрае некое време.",
     "This page will refresh itself when the instance is available again." : "Оваа веб страница ќе се рефрешира кога истанцата ќе биде повторно достапна.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Контактирајте го вашиот систем администратор до колку оваа порака продолжи да се појавува или пак се појавува ненадејно.",
-    "[%d / %d]: Checking table %s" : "[%d / %d]: Проверка на табела %s",
-    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Овој опслужувач нема работна Интернет врска. Ова значи дека некои опции како што е монтирање на надворешни складишта, известувања за ажурирање или инсталации на апликации од 3-ти лица нема да работат. Пристапот на датотеки од далечина и праќање на пораки за известувања може исто така да не работат. Ви советуваме да овозможите Интернет врска за овој опслужувач ако сакате да ги имате сите опции. ",
-    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 е последна верзија која поддржува PHP 7.2. За Nextcloud 21 потребна е PHP 7.3.",
-    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "Недостасува PHP модулот \"OPcache\". {linkstart}За да имате подобри перформанси е препорачливо ↗{linkend} да го овозможите во вашата PHP инсталација.",
-    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "PHP модулот \"OPcache\" не е правилно конфигуриран. {linkstart}За да имате подобри перформанси е препорачливо ↗{linkend} да ги користите следните поставки во вашата <code>php.ini</code> датотека:",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "За да мигрирате во друга база на податоци, користете ја алатката во командната линија: 'occ db:convert-type', или погледнете во {linkstart}документацијата ↗{linkend}.",
-    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Вашата папка за податоци и вашите датотеки се најверојатно достапни од интернет. Датотеката .htaccess не работи. Строго ви препорачуваме да го подесите вашиот веб опслужувач на начин на кој вашата папка за податоци не е веќе достапна од интернет или да ја преместите папката за податоци надвор од коренот на веб опслужувачот.",
-    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавието \"{header}\" не го содржи \"{expected}\". Ова потенцијално може да ја загрози приватноста и безбедноста, се препорачува соодветно да ја поставите оваа поставка.",
-    "Collaboratively edit office documents." : "Колаборативно уредување на документи.",
-    "restricted" : "ограничено",
-    "invisible" : "невидливо",
+    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Порака за ресетирање на лозинката е испратена на е-пошта на оваа сметка. Доколку не сте ја добиле, проверете во spam/junk папката или прашајте го вашиот локален администратор за помош.",
+    "If it is not there ask your local administrator." : "Доколку не е таму, прашајте го вашиот локален администратор.",
+    "Press enter to start searching" : "Притисни Enter за започне пребарувањето",
+    "Settings" : "Параметри",
     "File not found" : "Датотеката не е пронајдена",
     "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Документот не може да се пронајде на серверот. Можеби ова споделување е избришано или рекот за пристап му е истечен?",
-    "More" : "Повеќе",
-    "More apps menu" : "Мени за повеќе апликации",
-    "Settings menu" : "Мени за параметри",
-    "The password is wrong. Try again." : "Лозинката е погрешна. Обидите се повторно.",
-    "Setup two-factor authentication" : "Постави двофакторна автентикација",
-    "You haven't added any info yet" : "Сè уште немате додадено никакви информации",
-    "{user} hasn't added any info yet" : "{user} сè уште нема додадено никакви информации"
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Ве молиме користете ја командната линија за ажурирање бидејќи автоматското ажурирање е оневозможено во config.php.",
+    "The page could not be found on the server." : "Страницата не е пронајдена на серверот."
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
