@@ -3,11 +3,13 @@ OC.L10N.register(
     {
     "Cannot write into \"config\" directory!" : "Ezin da idatzi \"config\" karpetan!",
     "This can usually be fixed by giving the web server write access to the config directory." : "Hau normalean konpon daiteke web zerbitzariari konfigurazio direktoriorako idazteko sarbidea emanez.",
-    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Edo, config.php fitxategia irakurtzeko soilik mantendu nahi baduzu, ezarri \"config_is_read_only\" aukera 'egia' baliora barruan.",
+    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Bestela, config.php fitxategia irakurtzeko soilik mantendu nahi baduzu, ezarri bertan \"config_is_read_only\" aukerari 'egia' balioa.",
     "See %s" : "Ikusi %s",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "%1$s aplikazioaren fitxategiak ez dira behar bezala ordezkatu. Ziurtatu zerbitzariarekin bateragarria den bertsioa dela.",
+    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "%1$s aplikazioa ez dago edo zerbitzari honekiko bertsio bateraezina du. Mesedez egiaztatu aplikazioen karpeta.",
     "Sample configuration detected" : "Adibide-ezarpena detektatua",
-    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Detektatu da adibide-ezarpena kopiatu dela. Honek zure instalazioa apur dezake eta ez da onartzen. Irakurri dokumentazioa config.php fitxategia aldatu aurretik.",
+    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Adibide-ezarpena kopiatu dela detektatu da. Honek zure instalazioa apur dezake eta ez da onartzen. Irakurri dokumentazioa config.php fitxategia aldatu aurretik.",
+    "404" : "404",
+    "The page could not be found on the server." : "Orria ez da zerbitzarian aurkitu.",
     "%s email verification" : "%sposta elektronikoaren egiaztapena",
     "Email verification" : "Posta elektronikoaren egiaztapena",
     "Click the following button to confirm your email." : "Egin klik hurrengo botoian zure posta elektronikoa berresteko.",
@@ -30,21 +32,21 @@ OC.L10N.register(
     "The following databases are supported: %s" : "Hurrengo datu-baseak onartzen dira: %s",
     "The command line tool %s could not be found" : "Komando lerroko %s tresna ezin da aurkitu",
     "The library %s is not available." : "%s liburutegia ez dago eskuragarri.",
-    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "%1$sliburutegia %2$s baino handiagoa den bertsioa behar da - eskuragarri %3$s bertsioa.",
-    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "%1$s liburutegia %2$sbaino txikiagoa den bertsioa behar da - eskuragarri %3$s bertsioa.",
+    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "%1$sliburutegiaren %2$s bertsioa baino berriagoa behar da - %3$s bertsioa eskuragarri.",
+    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "%1$s liburutegiaren %2$sbertsioa baino txikiagoa behar da - %3$s bertsioa eskuragarri.",
     "The following platforms are supported: %s" : "Hurrengo plataformak onartzen dira: %s",
     "Server version %s or higher is required." : "Zerbitzariaren %s bertsioa edo berriagoa behar da.",
     "Server version %s or lower is required." : "Zerbitzariaren %s bertsioa edo zaharragoa behar da.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Saioa hasitako erabiltzailea administratzailea, azpiadministratzailea edo baimen berezi bat duena izan behar da ezarpen hau aldatzeko.",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Saioa hasitako erabiltzailea administratzailea, azpi-administratzailea edo baimen berezi bat duena izan behar da ezarpen hau aldatzeko.",
     "Logged in user must be an admin or sub admin" : "Saioa hasitako erabiltzailea administratzaile edo azpi-administratzailea izan behar du",
     "Logged in user must be an admin" : "Saioa hasitako erabiltzailea administratzailea izan behar da",
     "Wiping of device %s has started" : "%s gailuaren garbiketa hasi da",
     "Wiping of device »%s« has started" : "»%s« gailuaren garbiketa hasi da",
-    "»%s« started remote wipe" : "»%s« urruneko garbiketa hasi du",
+    "»%s« started remote wipe" : "»%s«(e)k urruneko garbiketa hasi du",
     "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "»%s« gailuak edo aplikazioak urruneko garbiketa prozesua hasi du. Prozesua amaitutakoan beste mezu elektroniko bat jasoko duzu",
     "Wiping of device %s has finished" : "%s gailuaren garbiketa amaitu da",
     "Wiping of device »%s« has finished" : "»%s« gailuaren garbiketa amaitu da",
-    "»%s« finished remote wipe" : "»%s« urruneko garbiketa amaitu du",
+    "»%s« finished remote wipe" : "»%s«(e)k urruneko garbiketa amaitu du",
     "Device or application »%s« has finished the remote wipe process." : "»%s« gailuak edo aplikazioak urruneko garbiketa prozesua amaitu du.",
     "Remote wipe started" : "Urruneko garbiketa hasi da",
     "A remote wipe was started on device %s" : "Urruneko garbiketa hasi da %s gailuan",
@@ -54,7 +56,9 @@ OC.L10N.register(
     "Unknown filetype" : "Fitxategi mota ezezaguna",
     "Invalid image" : "Baliogabeko irudia",
     "Avatar image is not square" : "Abatarreko irudia ez da karratua",
+    "Files" : "Fitxategiak",
     "View profile" : "Ikusi profila",
+    "Local time: %s" : "Ordu lokala: %s",
     "today" : "gaur",
     "tomorrow" : "bihar",
     "yesterday" : "atzo",
@@ -62,20 +66,20 @@ OC.L10N.register(
     "_%n day ago_::_%n days ago_" : ["orain dela egun %n","orain dela %n egun"],
     "next month" : "datorren hilabetea",
     "last month" : "joan den hilabetean",
-    "_in %n month_::_in %n months_" : ["hilabete %nean","%n hilabetetan"],
+    "_in %n month_::_in %n months_" : ["hilabete %nean","%n hilabete barru"],
     "_%n month ago_::_%n months ago_" : ["orain dela hilabete %n","orain dela %n hilabete"],
-    "next year" : "datorren urtea",
+    "next year" : "datorren urtean",
     "last year" : "joan den urtean",
-    "_in %n year_::_in %n years_" : ["urte %nean","%n urtetan"],
+    "_in %n year_::_in %n years_" : ["urte %nean","%n urte barru"],
     "_%n year ago_::_%n years ago_" : ["orain dela urte %n","orain dela %n urte"],
     "_in %n hour_::_in %n hours_" : ["ordu %n barru","%n ordu barru"],
     "_%n hour ago_::_%n hours ago_" : ["orain dela ordu %n","orain dela %n ordu"],
-    "_in %n minute_::_in %n minutes_" : ["minutu %nean","%n minututan"],
+    "_in %n minute_::_in %n minutes_" : ["minutu %nean","%n minutu barru"],
     "_%n minute ago_::_%n minutes ago_" : ["orain dela minutu %n","orain dela %n minutu"],
     "in a few seconds" : "segundo gutxitan",
-    "seconds ago" : "duela segundu batzuk",
+    "seconds ago" : "duela segundo batzuk",
     "Empty file" : "Fitxategi hutsa",
-    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "IDa duen modulua: %s ez da existitzen. Gaitu zure aplikazioen ezarpenetan edo jarri harremanetan administratzailearekin.",
+    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "%s IDa duen modulua ez da existitzen. Gaitu zure aplikazioen ezarpenetan edo jarri harremanetan administratzailearekin.",
     "File already exists" : "Badago izen bereko fitxategi bat",
     "Invalid path" : "Bide-izen baliogabea",
     "Failed to create file from template" : "Fitxategi berria txantiloitik sortzeak huts egin du",
@@ -84,11 +88,11 @@ OC.L10N.register(
     "File name contains at least one invalid character" : "Fitxategi izenak karaktere baliogabe bat du gutxienez ",
     "File name is too long" : "Fitxategi-izena luzeegia da",
     "Dot files are not allowed" : "Dot fitxategiak ez dira onartzen",
-    "Empty filename is not allowed" : "Fitxategiaren izena izin da hutsa izan",
+    "Empty filename is not allowed" : "Fitxategiaren izena ezin da hutsa izan",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "«%s» aplikazioa ezin da instalatu appinfo fitxategia ezin delako irakurri.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "\"%s\" aplikazioa ezin da instalatu ez delako zerbitzariaren bertsio honekin bateragarria.",
     "__language_name__" : "Euskara",
-    "This is an automatically sent email, please do not reply." : "Hau automatikoki bidalitako e-posta bat da, ez erantzun mesedez.",
+    "This is an automatically sent email, please do not reply." : "Hau automatikoki bidalitako mezua da, ez erantzun mesedez.",
     "Help" : "Laguntza",
     "Appearance and accessibility" : "Itxura eta irisgarritasuna",
     "Apps" : "Aplikazioak",
@@ -97,10 +101,12 @@ OC.L10N.register(
     "Settings" : "Ezarpenak",
     "Log out" : "Amaitu saioa",
     "Users" : "Erabiltzaileak",
-    "Email" : "E-posta",
-    "Mail %s" : "Bidali e-posta %s",
+    "Email" : "Posta elektronikoa",
+    "Mail %s" : "Idatzi %s(r)i",
+    "Fediverse" : "Fedibertsoa",
+    "View %s on the fediverse" : "Ikusi %s fedibertsoan",
     "Phone" : "Telefonoa",
-    "Call %s" : "Deitu %s",
+    "Call %s" : "Deitu %s(r)i",
     "Twitter" : "Twitter",
     "View %s on Twitter" : "Ikusi %s Twitterren",
     "Website" : "Webgunea",
@@ -108,48 +114,49 @@ OC.L10N.register(
     "Address" : "Helbidea",
     "Profile picture" : "Profil-irudia",
     "About" : "Honi buruz",
-    "Full name" : "Izen osoa",
+    "Display name" : "Erakusteko izena",
     "Headline" : "Izenburua",
     "Organisation" : "Erakundea",
     "Role" : "Zeregina",
     "Unknown user" : "Erabiltzaile ezezaguna",
     "Additional settings" : "Ezarpen gehiago",
-    "Enter the database username and name for %s" : "Sartu %s(r)en datu-base erabiltzaile-izen eta izena",
+    "Enter the database username and name for %s" : "%s sartu datu-basearen izena eta erabiltzaile-izena",
     "Enter the database username for %s" : "Sartu %s(r)en datu-base erabiltzaile-izena",
     "Enter the database name for %s" : "Sartu %s(r)en datu-base izena",
     "You cannot use dots in the database name %s" : "Ezin duzu punturik erabili %s datu-base izenean",
     "MySQL username and/or password not valid" : "MySQL erabiltzaile-izen edota pasahitza baliogabea",
     "You need to enter details of an existing account." : "Existitzen den kontu baten xehetasunak sartu behar dituzu.",
     "Oracle connection could not be established" : "Ezin da Oracle konexioa sortu",
-    "Oracle username and/or password not valid" : "Oracle erabiltzaile edota pasahitza ez dira egokiak.",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL erabiltzaile edota pasahitza ez dira egokiak.",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X-ek ez du sostengurik eta %s gaizki ibili daiteke plataforma honetan. Erabiltzekotan, zure ardurapean.",
-    "For the best results, please consider using a GNU/Linux server instead." : "Emaitza hobeak izateko, mesedez gogoan hartu GNU/Linux zerbitzari bat erabiltzea.",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Badirudi %s instantzia hau 32 biteko PHP ingurune bat exekutatzen ari dela eta open_basedir aldagaia php.ini fitxategian konfiguratu dela. Honek arazoak sortuko ditu 4 GB baino gehiagoko fitxategiekin eta ez da gomendatzen.",
+    "Oracle username and/or password not valid" : "Oracle erabiltzaile edo/eta pasahitza ez dira baliozkoak.",
+    "PostgreSQL username and/or password not valid" : "PostgreSQL erabiltzailea edo/eta pasahitza ez dira baliozkoak.",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X ez da onartzen eta %s gaizki ibiliko da plataforma honetan. Erabiltzekotan, zure ardurapean.",
+    "For the best results, please consider using a GNU/Linux server instead." : "Emaitza hobeak izateko, mesedez kontsideratu GNU/Linux zerbitzari bat erabiltzea.",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Badirudi %s instantzia hau 32 biteko PHP ingurune bat exekutatzen ari dela eta open_basedir aldagaia php.ini fitxategian konfiguratu dela. Honek arazoak sortuko ditu 4 GB baino gehiagoko fitxategiekin eta ez da batere gomendagarria.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Mesedez kendu open_basedir ezarpena zure php.ini-tik edo aldatu 64-biteko PHPra.",
     "Set an admin username." : "Ezarri administraziorako erabiltzaile izena.",
     "Set an admin password." : "Ezarri administraziorako pasahitza.",
     "Cannot create or write into the data directory %s" : "Ezin da sortu edo idatzi %s datu-direktorioan ",
-    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "%s elkarbanaketa motorra  OCP\\Share_Backend interfazea inplementatu behar du ",
-    "Sharing backend %s not found" : "Ez da %s elkarbanaketa motorra aurkitu",
-    "Sharing backend for %s not found" : "Ez da %srako elkarbanaketa motorrik aurkitu",
+    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "%s partekatze motorrak OCP\\Share_Backend interfazea inplementatu behar du ",
+    "Sharing backend %s not found" : "Ez da %s partekatze motorra aurkitu",
+    "Sharing backend for %s not found" : "Ez da %s(e)rako partekatze motorrik aurkitu",
     "%1$s shared »%2$s« with you and wants to add:" : "%1$serabiltzaileak »%2$s« partekatu du zurekin eta hau gehitu nahi du:",
     "%1$s shared »%2$s« with you and wants to add" : "%1$serabiltzaileak »%2$s« partekatu du zurekin eta hau gehitu nahi du",
-    "»%s« added a note to a file shared with you" : "»%s« erabiltzaileak nota bat gehitu dio partekatu dizun fitxategi batean",
+    "»%s« added a note to a file shared with you" : "»%s« erabiltzaileak ohar bat gehitu du partekatu dizun fitxategi batean",
     "Open »%s«" : "Ireki »%s«",
     "%1$s via %2$s" : "%2$s bidez, %1$s",
-    "You are not allowed to share %s" : "Ez zadue %s elkarbanatzeko baimendua",
-    "Cannot increase permissions of %s" : "Ezin dira %s -(r)en baimenak handitu",
+    "You are not allowed to share %s" : "Ez duzu %s partekatzeko baimenik",
+    "Cannot increase permissions of %s" : "Ezin dira %s(r)en baimenak handitu",
     "Files cannot be shared with delete permissions" : "Fitxategiak ezin dira ezabatze baimenarekin partekatu",
     "Files cannot be shared with create permissions" : "Fitxategiak ezin dira sortze baimenarekin partekatu",
     "Expiration date is in the past" : "Iraungitze-data iraganean dago",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Ezin da iraungitze-data etorkizunean %n egun baino gehiagora jarri","Ezin da iraungitze-data etorkizunean %n egun baino gehiagora jarri"],
-    "Sharing is only allowed with group members" : "Partekatzea taldeko kideei baimenduta dago soilik",
+    "Sharing is only allowed with group members" : "Taldeko kideekin bakarrik parteka daiteke",
     "Sharing %s failed, because this item is already shared with user %s" : "%s partekatzeak huts egin du dagoeneko %serabiltzailearekin partekatuta dagoelako",
     "%1$s shared »%2$s« with you" : "%1$serabiltzaileak »%2$s« partekatu du zurekin",
-    "%1$s shared »%2$s« with you." : "%1$serabiltzaileak »%2$s« partekatu du zurekin",
-    "Click the button below to open it." : "Egin klik beheko botoian hura irekitzeko",
+    "%1$s shared »%2$s« with you." : "%1$serabiltzaileak »%2$s« partekatu du zurekin.",
+    "Click the button below to open it." : "Egin klik beheko botoian hura irekitzeko.",
     "The requested share does not exist anymore" : "Eskatutako partekatzea ez da existitzen dagoeneko",
+    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Ezin izan da erabiltzailea sortu, erabiltzaile muga gainditu delako. Egiaztatu zure jakinarazpenak gehiago jakiteko.",
     "Could not find category \"%s\"" : "Ezin da \"%s\" kategoria aurkitu",
     "Sunday" : "Igandea",
     "Monday" : "Astelehena",
@@ -196,17 +203,16 @@ OC.L10N.register(
     "Oct." : "Urr.",
     "Nov." : "Aza.",
     "Dec." : "Abe.",
-    "The user limit has been reached and the user was not created." : "Erabiltzaile mugara heldu da eta ez da erabiltzailea sortu.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Erabiltzaile-izenean karaktere hauek soilik erabili daitezke: \"a-z\", \"A-Z\", \"0-9\", eta \"_.@-'\"",
+    "A valid password must be provided" : "Baliozko pasahitza eman behar da",
+    "The username is already being used" : "Erabiltzaile izena dagoeneko erabilita dago",
+    "Could not create user" : "Ezin izan da erabiltzailea sortu",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Honako karaktereak bakarrik onartzen dira erabiltzaile izenetan: \"a-z\", \"A-Z\", \"0-9\", zuriuneak eta \"_.@-'\"",
     "A valid username must be provided" : "Baliozko erabiltzaile izena eman behar da",
     "Username contains whitespace at the beginning or at the end" : "Erabiltzaile-izenak zuriuneren bat du hasieran edo amaieran",
     "Username must not consist of dots only" : "Erabiltzaile-izena ezin da puntuz osatuta soilik egon",
-    "Username is invalid because files already exist for this user" : "Erabiltzaile-izena ez da baliozkoa fitxategiak erabiltzaile honentzat existitzen direlako dagoeneko",
-    "A valid password must be provided" : "Baliozko pasahitza eman behar da",
-    "The username is already being used" : "Erabiltzaile izena dagoeneko erabiltzen ari da",
-    "Could not create user" : "Ezin izan da erabiltzailea sortu",
+    "Username is invalid because files already exist for this user" : "Erabiltzaile-izena ez da baliozkoa erabiltzaile honentzako fitxategiak dagoeneko existitzen direlako",
     "User disabled" : "Erabiltzaile desgaituta",
-    "Login canceled by app" : "Aplikazioa saioa bertan behera utzi du",
+    "Login canceled by app" : "Aplikazioak saioa bertan behera utzi du",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "\"%1$s\" aplikazioa ezin da instalatu, menpekotasun hauek betetzen ez direlako:%2$s",
     "a safe home for all your data" : "zure datu guztientzako toki segurua",
     "File is currently busy, please try again later" : "Fitxategia lanpetuta dago, saiatu berriro geroago",
@@ -217,33 +223,31 @@ OC.L10N.register(
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Ez dago datubaseen (sqlite, mysql edo postgresql) driverrik instalatuta.",
     "Cannot write into \"config\" directory." : "Ezin da \"config\" karpetan idatzi.",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Hau normalean konpondu daiteke web zerbitzariari konfigurazio direktoriorako sarbidea emanez. Ikus %s",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Edo, config.php fitxategia irakurtzeko soilik mantendu nahi baduzu, ezarri \"config_is_read_only\" aukera 'egia' baliora barruan. Ikusi %s",
+    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Bestela, config.php fitxategia irakurtzeko soilik mantendu nahi baduzu, ezarri bertan \"config_is_read_only\" aukerari 'egia' balioa. Ikusi %s",
     "Cannot write into \"apps\" directory." : "Ezin da idatzi \"apps\" fitxategian.",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Hau normalean konpondu daiteke web zerbitzariari aplikazioen direktorioko sarbidea emanez edo konfigurazioko fitxategian App Store desgaituz.",
-    "Cannot create \"data\" directory." : "Ezin da \"data\" fitxategia sortu.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Hau normalean konpondu daiteke web zerbitzariari aplikazioen direktorioko sarbidea emanez edo konfigurazioko fitxategian aplikazioen biltegia (App Store) desgaituz.",
+    "Cannot create \"data\" directory." : "Ezin da \"data\" direktorioa sortu.",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Hau normalean konpondu daiteke web zerbitzariari root direktorioko idazketa sarbidea emanez. Ikus %s",
-    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : " 99% match \nNormalean baimenak konpondu daitezke web zerbitzariari root direktorioko sarbidea emanez. Ikus%s.",
+    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Normalean baimenak konpondu daitezke web zerbitzariari root direktorioko sarbidea emanez. Ikus%s.",
     "Your data directory is not writable." : "Zure datuen karpeta ez da idazgarria.",
-    "Setting locale to %s failed." : "Lokala %sra ezartzeak huts egin du",
-    "Please install one of these locales on your system and restart your web server." : "Mesedez, instalatu lokal hauetako bat zure sisteman eta berrabiarazi zure web zerbitzaria.",
+    "Setting locale to %s failed." : "Eskualde-ezarpenak %s(e)ra ezartzeak huts egin du",
+    "Please install one of these locales on your system and restart your web server." : "Mesedez, instalatu eskualde-ezarpen hauetako bat zure sisteman eta berrabiarazi zure web zerbitzaria.",
     "PHP module %s not installed." : "PHPren %s modulua ez dago instalaturik.",
-    "Please ask your server administrator to install the module." : "Mesedez eskatu zure zerbitzariaren kudeatzaileari modulua instala dezan.",
+    "Please ask your server administrator to install the module." : "Mesedez eskatu zure zerbitzariaren administratzaileari modulua instalatzeko.",
     "PHP setting \"%s\" is not set to \"%s\"." : "\"%s\" PHP ezarpena ez dago \"%s\" gisa jarrita.",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Ezarpen hau php.ini fitxategian doitzen bada, Nextcloud berriro exekutatuko da",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code><code>%s</code>-en ezartzen da espero den <code>0</code> balioaren ordez.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Arazo hau konpontzeko, ezarri<code>mbstring.func_overload</code> <code>0</code>-n zure php.ini-n.",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 bertsioa edo berriagoa behar da. Orain %s dago instalatuta.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Arazo hori konpontzeko, eguneratu zure libxml2 bertsioa eta berrabiarazi web zerbitzaria.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code><code>%s</code>-en ezarrita dago, espero zen <code>0</code> balioaren ordez.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Arazo hau konpontzeko, ezarri<code>mbstring.func_overload</code> <code>0</code>-en zure php.ini fitxategian.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP lerro bakarreko blokeak mozteko konfiguratua dagoela dirudi. Oinarrizko app batzuk eskuraezin bihurtuko dira.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Hau ziur aski cache/accelerator batek eragin du, hala nola Zend OPcache edo eAccelerator.",
-    "PHP modules have been installed, but they are still listed as missing?" : "PHP moduluak instalatu dira, baina oraindik faltan bezala markatuta daude?",
-    "Please ask your server administrator to restart the web server." : "Mesedez eskatu zerbitzariaren kudeatzaileari web zerbitzaria berrabiarazteko.",
+    "PHP modules have been installed, but they are still listed as missing?" : "PHP moduluak instalatu dira, baina oraindik falta direla jartzen du?",
+    "Please ask your server administrator to restart the web server." : "Mesedez eskatu zerbitzariaren administratzaileari web zerbitzaria berrabiarazteko.",
     "The required %s config variable is not configured in the config.php file." : "Beharrezko %s config aldagaia ez dago konfiguratuta config.php fitxategian.",
-    "Please ask your server administrator to check the Nextcloud configuration." : "Mesedez, eskatu zure zerbitzari-administratzaileari Nextcloud-en konfigurazioa egiaztatzeko.",
+    "Please ask your server administrator to check the Nextcloud configuration." : "Mesedez, eskatu zure zerbitzari administratzaileari Nextclouden konfigurazioa egiaztatzeko.",
     "PostgreSQL >= 9 required." : "PostgreSQL >= 9 behar da",
     "Please upgrade your database version." : "Mesedez eguneratu zure datu-basearen bertsioa.",
     "Your data directory is readable by other users." : "Zure datuen karpeta beste erabiltzaileek irakur dezakete.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Mesedez aldatu baimenak 0770ra beste erabiltzaileek karpetan sartu ezin izateko.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Aldatu baimenak 0770ra beste erabiltzaileek karpetan sartu ezin izateko.",
     "Your data directory must be an absolute path." : "Zure datuen karpeta bide-izen absolutua izan behar da.",
     "Check the value of \"datadirectory\" in your configuration." : "Egiaztatu \"datadirectory\"-ren balioa zure konfigurazioan.",
     "Your data directory is invalid." : "Zure datuen karpeta baliogabea da.",
@@ -251,36 +255,20 @@ OC.L10N.register(
     "Action \"%s\" not supported or implemented." : "\"%s\" ekintza ez da onartzen edo ez dago inplementaturik.",
     "Authentication failed, wrong token or provider ID given" : "Autentifikazioak huts egin du, token edo hornitzaile ID okerra eman da",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Eskaera osatzeko parametroak falta dira. Falta diren parametroak: \"%s\"",
-    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "\"%2$s\" hodei federazio-hornitzaileak dagoeneko erabiltzen duen \"%1$s\" IDa",
-    "Cloud Federation Provider with ID: \"%s\" does not exist." : "IDa duen hodei federazio-hornitzailea: \"%s\" ez da existitzen.",
-    "Could not obtain lock type %d on \"%s\"." : "Ezin da lortu sarraia mota %d \"%s\"-an.",
+    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : " \"%1$s\" IDa dagoeneko erabiltzen du \"%2$s\" hodei federazio hornitzaileak",
+    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Hodei federazio hornitzaile IDa: \"%s\" ez da existitzen.",
+    "Could not obtain lock type %d on \"%s\"." : "Ezin da lortu %d sarraila mota \"%s\"(e)n.",
     "Storage unauthorized. %s" : "Biltegiratzea ez dago baimenduta. %s",
-    "Storage incomplete configuration. %s" : "Biltegiratzea ez da osorik konfiguratu. %s",
+    "Storage incomplete configuration. %s" : "Biltegiratzea guztiz konfiguratu gabe dago. %s",
     "Storage connection error. %s" : "Biltegiratze-konexioaren errorea. %s",
     "Storage is temporarily not available" : "Biltegia ez dago erabilgarri aldi baterako",
     "Storage connection timeout. %s" : "Biltegiratze-konexioa denboraz kanpo geratu da. %s",
-    "This can usually be fixed by giving the webserver write access to the config directory." : "Hau normalean web zerbitzarira config karpetan idazteko baimenak emanez konpondu daiteke.",
-    "%s enter the database username and name." : "%s sartu datu-basearen erabiltzaile-izena eta izena.",
-    "%s enter the database username." : "%s sartu datu basearen erabiltzaile izena.",
-    "%s enter the database name." : "%s sartu datu basearen izena.",
-    "%s you may not use dots in the database name" : "%s ezin duzu punturik erabili datu basearen izenean.",
-    "Cannot read file" : "Ezin da fitxategia irakurri",
-    "Cannot write into \"config\" directory" : "Ezin da idatzi \"config\" karpetan",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Hau normalean konpondu daiteke web zerbitzariari konfigurazio direktoriorako sarbidea emanez. Ikus %s",
-    "Cannot write into \"apps\" directory" : "Ezin da idatzi \"apps\" karpetan",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Hau normalean web zerbitzariari aplikazioen direktorioko sarbidea emanez edo konfigurazioko fitxategian appstore desgaituz konpondu daiteke.",
-    "Cannot create \"data\" directory" : "Ezin da \"data\" karpeta sortu",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Hau normalean konpondu daiteke web zerbitzariari root direktorioko idazketa sarbidea emanez. Ikus %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Normalean baimenak konpondu daitezke web zerbitzariari root direktorioko sarbidea emanez. Ikus %s.",
-    "Setting locale to %s failed" : "Lokala %sra ezartzeak huts egin du",
-    "Please install one of these locales on your system and restart your webserver." : "Instalatu hauetako lokal bat zure sisteman eta berrabiarazi zure web zerbitzaria.",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload \"%s\"-(e)ra ezarrita dago \"0\" itxarondako balioaren ordez",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Arazo hau konpontzeko ezarri <code>mbstring.func_overload</code> <code>0</code>-ra zure php.ini fitxategian",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 behar da",
-    "Please upgrade your database version" : "Mesedez eguneratu zure datu basearen bertsioa",
-    "Your data directory is readable by other users" : "Zure datuen karpeta beste erabiltzaileek irakur dezakete",
-    "Your data directory must be an absolute path" : "Zure datuen karpeta bide-izen absolutua izan behar da",
-    "Check the value of \"datadirectory\" in your configuration" : "Egiaztatu «datadirectory» aldagaiaren balioa zure konfigurazioan",
-    "Your data directory is invalid" : "Zure datuen karpeta baliogabea da"
+    "Free prompt" : "Gonbita librea",
+    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "%1$s aplikazioaren fitxategiak ez dira behar bezala ordezkatu. Ziurtatu zerbitzariarekin bateragarria den bertsioa dela.",
+    "Full name" : "Izen osoa",
+    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "Ezin izan da erabiltzailea sortu, erabiltzaile muga gainditu delako. Egiaztatu zure jakinarazpenak gehiago jakiteko.",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Erabiltzaile-izenean karaktere hauek soilik erabil daitezke: \"a-z\", \"A-Z\", \"0-9\", eta \"_.@-'\"",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 bertsioa edo berriagoa behar da. Orain %s dago instalatuta.",
+    "To fix this issue update your libxml2 version and restart your web server." : "Arazo hori konpontzeko, eguneratu zure libxml2 bertsioa eta berrabiarazi web zerbitzaria."
 },
 "nplurals=2; plural=(n != 1);");
