@@ -5,7 +5,6 @@ OC.L10N.register(
     "This can usually be fixed by giving the web server write access to the config directory." : "通常可以为 Web 服务器授予对 config 目录的写入权限来修复这个问题。",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "但是，如果您更希望将 config.php 文件设为只读，可以将 \"config_is_read_only\" 选项设置为 true。",
     "See %s" : "查看 %s",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "应用%1$s的文件替换不正确。请确认版本与当前服务器兼容。",
     "Sample configuration detected" : "示例配置检测",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "您似乎直接把 config.php 的样例文件直接复制使用。这可能会破坏您的安装。在对 config.php 进行修改之前请先阅读相关文档。",
     "404" : "404",
@@ -56,7 +55,9 @@ OC.L10N.register(
     "Unknown filetype" : "未知的文件类型",
     "Invalid image" : "无效的图像",
     "Avatar image is not square" : "头像图像不是正方形",
+    "Files" : "文件",
     "View profile" : "查看个人资料",
+    "Local time: %s" : "当地时间：%s",
     "today" : "今天",
     "tomorrow" : "明天",
     "yesterday" : "昨天",
@@ -71,9 +72,9 @@ OC.L10N.register(
     "_in %n year_::_in %n years_" : ["%n年内"],
     "_%n year ago_::_%n years ago_" : ["%n 年前"],
     "_in %n hour_::_in %n hours_" : ["%n小时内"],
-    "_%n hour ago_::_%n hours ago_" : ["%n 小时前"],
+    "_%n hour ago_::_%n hours ago_" : ["%n小时前"],
     "_in %n minute_::_in %n minutes_" : ["%n分钟内"],
-    "_%n minute ago_::_%n minutes ago_" : ["%n 分钟前"],
+    "_%n minute ago_::_%n minutes ago_" : ["%n分钟前"],
     "in a few seconds" : "几秒钟内",
     "seconds ago" : "几秒前",
     "Empty file" : "空文件",
@@ -101,16 +102,18 @@ OC.L10N.register(
     "Users" : "用户",
     "Email" : "电子邮箱",
     "Mail %s" : "发邮件给 %s",
+    "Fediverse" : "联邦宇宙",
+    "View %s on the fediverse" : "在联邦宇宙上浏览%s",
     "Phone" : "电话",
     "Call %s" : "呼叫 %s",
-    "Twitter" : "推特",
-    "View %s on Twitter" : "在推特上查看 %s",
+    "Twitter" : "Twitter",
+    "View %s on Twitter" : "在Twitter上查看 %s",
     "Website" : "网站",
     "Visit %s" : "访问 %s",
     "Address" : "地址",
     "Profile picture" : "个人资料图片 ",
     "About" : "关于",
-    "Full name" : "全名",
+    "Display name" : "显示用户名",
     "Headline" : "标题",
     "Organisation" : "组织",
     "Role" : "角色",
@@ -127,6 +130,8 @@ OC.L10N.register(
     "PostgreSQL username and/or password not valid" : "PostgreSQL 数据库用户名和/或密码无效",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X 不被支持并且 %s 在这个平台上无法正常工作。请自行承担风险！",
     "For the best results, please consider using a GNU/Linux server instead." : "为了达到最好的效果，请考虑使用 GNU/Linux 服务器。",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "看起来这个 %s 实例运行在32位 PHP 环境中并且已在 php.ini 中配置open_basedir。这将在文件超过4GB时出现问题，强烈不建议这样做。",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "请删除 php.ini 中的 open_basedir 设置或切换到64位PHP。",
     "Set an admin username." : "请设置一个管理员用户名。",
     "Set an admin password." : "请设置一个管理员密码。",
     "Cannot create or write into the data directory %s" : "无法创建或写入数据文件夹 %s",
@@ -150,7 +155,6 @@ OC.L10N.register(
     "%1$s shared »%2$s« with you." : "%1$s 对您共享了 »%2$s«。",
     "Click the button below to open it." : "点击下方按钮可打开它。",
     "The requested share does not exist anymore" : "当前请求的共享已经不存在",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "已达到用户上限，未创建该用户。请检查您的通知以了解更多。",
     "Could not find category \"%s\"" : "无法找到分类 \"%s\"",
     "Sunday" : "星期日",
     "Monday" : "星期一",
@@ -197,14 +201,13 @@ OC.L10N.register(
     "Oct." : "十月",
     "Nov." : "十一月",
     "Dec." : "十二月",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "在用户名中只允许使用以下字符：“a-z”、“A-Z”、“0-9” 和 \"_.@-'\"",
+    "A valid password must be provided" : "必须提供合法的密码",
+    "The username is already being used" : "用户名已被使用",
+    "Could not create user" : "无法创建用户",
     "A valid username must be provided" : "必须提供合法的用户名",
     "Username contains whitespace at the beginning or at the end" : "用户名在开头或结尾处包含空格",
     "Username must not consist of dots only" : "用户名不能仅由点组成",
     "Username is invalid because files already exist for this user" : "用户名无效，因为该用户已经存在文件",
-    "A valid password must be provided" : "必须提供合法的密码",
-    "The username is already being used" : "用户名已被使用",
-    "Could not create user" : "无法创建用户",
     "User disabled" : "用户已禁用",
     "Login canceled by app" : "已通过应用取消登录",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "应用 \"%1$s\" 无法安装，因为不能满足以下依赖： %2$s",
@@ -224,7 +227,7 @@ OC.L10N.register(
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "通常可以为 Web 服务器授予对根目录的写入权限来修复这个问题。查看：%s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "通常可以为 Web 服务器授予对根目录的写入权限来修复权限问题。查看：%s。",
     "Your data directory is not writable." : "您的数据目录无法写入。",
-    "Setting locale to %s failed." : "设置语言为 %s 失败。",
+    "Setting locale to %s failed." : "设置语言为%s失败。",
     "Please install one of these locales on your system and restart your web server." : "请在您的系统中安装下述一种语言并重启 Web 服务器。",
     "PHP module %s not installed." : "PHP %s 模块未安装。",
     "Please ask your server administrator to install the module." : "请联系您的服务器管理员安装模块。",
@@ -232,8 +235,6 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make Nextcloud run again" : "在 php.ini 中调整该设置将导致 Nextcloud 重新运行",
     "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code>被设置为<code>%s</code>，而不是预期的 <code>0</code>。",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "为了修正该问题，请在您的 php.ini 中设置<code>mbstring.func_overload</code>为<code>0</code>。",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "至少需要 libxml2 2.7.0. 当前安装 %s。",
-    "To fix this issue update your libxml2 version and restart your web server." : "升级您的 libxml2 版本然后重启 Web 服务器以解决该问题。",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP 被设置为移除内联块，这将导致多个核心应用无法访问。",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "这可能由缓存/加速器导致的，例如 Zend OPcache 或 eAccelerator。",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP 模块已经安装，但仍然显示未安装？",
@@ -251,39 +252,19 @@ OC.L10N.register(
     "Action \"%s\" not supported or implemented." : "操作 \"%s\" 不支持或未实现。",
     "Authentication failed, wrong token or provider ID given" : "认证失败，提供了错误的token或提供者ID",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "缺少参数来完成请求。缺少的参数为：\"%s\"",
-    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" 已被联合云提供商 \"%2$s\" 使用",
-    "Cloud Federation Provider with ID: \"%s\" does not exist." : "ID为 \"%s\" 的联合云提供商不存在。",
+    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID“%1$s”已被联合云提供商“%2$s”使用",
+    "Cloud Federation Provider with ID: \"%s\" does not exist." : "ID为“%s”的联合云提供商不存在。",
     "Could not obtain lock type %d on \"%s\"." : "无法在 \"%s\" 上获取锁类型 %d。",
     "Storage unauthorized. %s" : "存储认证失败。%s",
     "Storage incomplete configuration. %s" : "存储未完成配置。%s",
     "Storage connection error. %s" : "存储连接错误。%s",
     "Storage is temporarily not available" : "存储暂时不可用",
     "Storage connection timeout. %s" : "存储连接超时。%s",
-    "This can usually be fixed by giving the webserver write access to the config directory." : "通常可以为 Web 服务器授予对 config 目录的写入权限来修复这个问题。",
-    "%s enter the database username and name." : "%s 输入数据库用户名和名称。",
-    "%s enter the database username." : "%s 输入数据库用户名。",
-    "%s enter the database name." : "%s 输入数据库名称。",
-    "%s you may not use dots in the database name" : "%s 您不能在数据库名称中使用英文句号。",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "看起来这个 %s 实例运行在32位 PHP 环境中并且已在 php.ini 中配置open_basedir。这将在文件超过4GB时出现问题，强烈不建议这样做。",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "请删除 php.ini 中的 open_basedir 设置或切换到64位PHP。",
-    "The user limit has been reached and the user was not created." : "已达到用户上限，未创建该用户。",
-    "Cannot read file" : "无法读取文件",
-    "Cannot write into \"config\" directory" : "无法写入“config”目录",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "通常可以为 Web 服务器授予对 config 目录的写入权限来修复这个问题。查看：%s",
-    "Cannot write into \"apps\" directory" : "无法写入“apps”目录",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "通常可以为 Web 服务器授予对 apps 目录的写入权限来修复这个问题，或在设置文件中禁用应用商店。",
-    "Cannot create \"data\" directory" : "无法创建“data”目录 ",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "通常可以为 Web 服务器授予对 config 目录的写入权限来修复这个问题。查看：%s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "通常可以为 Web 服务器授予对 config 目录的写入权限来修复权限问题。查看：%s。",
-    "Setting locale to %s failed" : "设置语言为 %s 失败",
-    "Please install one of these locales on your system and restart your webserver." : "请在您的系统中安装下述一种语言并重启 Web 服务器。",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload 当前设置为 \"%s\"，预期值为 \"0\"",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "请在 php.ini 中设置  <code>mbstring.func_overload</code> 为 <code>0</code> 以解决该问题",
-    "PostgreSQL >= 9 required" : "需要 PostgreSQL >= 9",
-    "Please upgrade your database version" : "请升级您的数据库版本",
-    "Your data directory is readable by other users" : "您的数据目录可被其他用户读取",
-    "Your data directory must be an absolute path" : "您的数据目录必须是绝对路径",
-    "Check the value of \"datadirectory\" in your configuration" : "请检查配置文件中 \"datadirectory\" 的值",
-    "Your data directory is invalid" : "您的数据目录无效"
+    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "应用%1$s的文件替换不正确。请确认版本与当前服务器兼容。",
+    "Full name" : "全名",
+    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "已达到用户上限，未创建该用户。请检查您的通知以了解更多。",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "在用户名中只允许使用以下字符：“a-z”、“A-Z”、“0-9” 和 \"_.@-'\"",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "至少需要 libxml2 2.7.0. 当前安装 %s。",
+    "To fix this issue update your libxml2 version and restart your web server." : "升级您的libxml2版本然后重启Web服务器以解决该问题。"
 },
 "nplurals=1; plural=0;");
