@@ -5,7 +5,7 @@ OC.L10N.register(
     "This can usually be fixed by giving the web server write access to the config directory." : "允許網頁伺服器寫入 config 目錄通常可以解決這個問題。",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "但如果您比較希望保留 config.php 的唯讀狀態，請在該設定檔中將 \"config_is_read_only\" 設定為 true。",
     "See %s" : "見 %s",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "應用程式 %1$s 中的檔案沒有被正確取代，請確認它的版本與伺服器相容。",
+    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "應用程式 %1$s 不存在或有與此伺服器不相容的版本。請檢查應用程式目錄。",
     "Sample configuration detected" : "您目前正在使用範例設定",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "您似乎直接複製了範例設定來使用，這樣的安裝很可能會無法運作，請閱讀說明文件後對 config.php 進行適當的修改",
     "404" : "404",
@@ -56,7 +56,9 @@ OC.L10N.register(
     "Unknown filetype" : "未知的檔案類型",
     "Invalid image" : "無效的圖片",
     "Avatar image is not square" : "頭像不是正方形",
+    "Files" : "檔案",
     "View profile" : "檢視個人檔案",
+    "Local time: %s" : "本機時間：%s",
     "today" : "今天",
     "tomorrow" : "明天",
     "yesterday" : "昨天",
@@ -101,6 +103,8 @@ OC.L10N.register(
     "Users" : "使用者",
     "Email" : "電子郵件",
     "Mail %s" : "傳送郵件給 %s",
+    "Fediverse" : "Fediverse",
+    "View %s on the fediverse" : "在 fediverse 上檢視 %s",
     "Phone" : "手機",
     "Call %s" : "與 %s 通話",
     "Twitter" : "Twitter",
@@ -110,7 +114,7 @@ OC.L10N.register(
     "Address" : "地址",
     "Profile picture" : "個人檔案圖片",
     "About" : "關於",
-    "Full name" : "全名",
+    "Display name" : "顯示名稱",
     "Headline" : "標題",
     "Organisation" : "組織",
     "Role" : "角色",
@@ -127,6 +131,8 @@ OC.L10N.register(
     "PostgreSQL username and/or password not valid" : "PostgreSQL 用戶名和/或密碼無效",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "不支援 Mac OS X 而且 %s 在這個平台上面無法正常運作，請自行衡量風險後使用！",
     "For the best results, please consider using a GNU/Linux server instead." : "請考慮使用 GNU/Linux 伺服器以獲得最佳體驗",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "看起來 %s 是在 32 位元的 PHP 環境運行，並且 php.ini 中被設置了 open_basedir 參數，這將讓超過 4GB 的檔案操作發生問題，強烈建議您更改設定。",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "請移除 php.ini 中的 open_basedir 設定，或是改用 64 位元的 PHP",
     "Set an admin username." : "設定管理員帳號",
     "Set an admin password." : "設定管理員密碼",
     "Cannot create or write into the data directory %s" : "無法建立或寫入資料目錄 %s",
@@ -150,7 +156,7 @@ OC.L10N.register(
     "%1$s shared »%2$s« with you." : "%1$s 與您分享了 %2$s",
     "Click the button below to open it." : "點下方連結開啟",
     "The requested share does not exist anymore" : "該分享已經不存在",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "已達使用者限制，所以未建立使用者。請檢查您的通知以取得更多資訊。",
+    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "未建立使用者，因為已達使用者上限。請檢查您的通知以取得更多資訊。",
     "Could not find category \"%s\"" : "找不到分類：\"%s\"",
     "Sunday" : "週日",
     "Monday" : "週一",
@@ -197,14 +203,14 @@ OC.L10N.register(
     "Oct." : "十月",
     "Nov." : "十一月",
     "Dec." : "十二月",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "使用者名稱當中只能包含下列字元：\"a-z\", \"A-Z\", \"0-9\", 和 \"_.@-'\"",
+    "A valid password must be provided" : "須提供有效的密碼",
+    "The username is already being used" : "這個使用者名稱已經有人使用了",
+    "Could not create user" : "無法建立使用者",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "使用者名稱僅允許以下字元：\"a-z\"、\"A-Z\"、\"0-9\"、空格與 \"_.@-'\"",
     "A valid username must be provided" : "必須提供一個有效的用戶名",
     "Username contains whitespace at the beginning or at the end" : "用戶名的開頭或結尾有空白",
     "Username must not consist of dots only" : "使用者名稱不能只包含小數點",
     "Username is invalid because files already exist for this user" : "使用者名稱無效，因為使用者的檔案已經存在",
-    "A valid password must be provided" : "須提供有效的密碼",
-    "The username is already being used" : "這個使用者名稱已經有人使用了",
-    "Could not create user" : "無法建立使用者",
     "User disabled" : "使用者已停用",
     "Login canceled by app" : "應用程式取消了登入",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "應用程式 \"%1$s\" 無法被安裝，缺少下列所需元件： %2$s",
@@ -232,8 +238,6 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make Nextcloud run again" : "調整 php.ini 中的設定，使 Nextcloud 重新運作",
     "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> 被設定為 <code>%s</code> 而非預期中的 <code>0</code>。",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "為了修正這個問題，請到 php.ini 將 <code>mbstring.func_overload</code> 的值改為 <code>0</code>。",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 版本最低需求為 2.7.0。目前安裝版本為 %s 。",
-    "To fix this issue update your libxml2 version and restart your web server." : "修正方式為更新您的 libxml2 為 2.7.0 以上版本，再重啟網頁伺服器。",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP 已經設定成「剪除 inline doc block」模式，這將會使幾個核心應用程式無法使用",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "這大概是由快取或是加速器像是 Zend OPcache, eAccelerator 造成的",
     "PHP modules have been installed, but they are still listed as missing?" : "你已經安裝了指定的 PHP 模組，可是還是顯示為找不到嗎？",
@@ -259,31 +263,18 @@ OC.L10N.register(
     "Storage connection error. %s" : "儲存空間連線錯誤。%s",
     "Storage is temporarily not available" : "儲存空間暫時無法使用",
     "Storage connection timeout. %s" : "儲存空間連線逾時。%s",
-    "This can usually be fixed by giving the webserver write access to the config directory." : "允許網頁伺服器寫入 \"config\" 目錄通常可以解決這個問題",
-    "%s enter the database username and name." : "%s 輸入資料庫名稱及使用者名稱",
-    "%s enter the database username." : "%s 輸入資料庫使用者名稱",
-    "%s enter the database name." : "%s 輸入資料庫名稱",
-    "%s you may not use dots in the database name" : "%s 資料庫名稱不能包含小數點",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "看起來 %s 是在 32 位元的 PHP 環境運行，並且 php.ini 中被設置了 open_basedir 參數，這將讓超過 4GB 的檔案操作發生問題，強烈建議您更改設定。",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "請移除 php.ini 中的 open_basedir 設定，或是改用 64 位元的 PHP",
-    "The user limit has been reached and the user was not created." : "已達使用者限制，所以未建立使用者。",
-    "Cannot read file" : "無法讀取檔案",
-    "Cannot write into \"config\" directory" : "無法寫入 config 目錄",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "允許網頁伺服器寫入 \"config\" 目錄通常可以解決這個問題，詳見 %s",
-    "Cannot write into \"apps\" directory" : "無法寫入 apps 目錄",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "允許網頁伺服器寫入應用程式的目錄或是在設定檔中停用應用程式商店通常可以解決這個問題。",
-    "Cannot create \"data\" directory" : "無法建立 \"data\" 目錄",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "開放網頁伺服器存取根目錄通常就可以修正這個問題，詳見 %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "開放網頁伺服器存取根目錄通常就可以修正權限問題，詳見 %s",
-    "Setting locale to %s failed" : "設定語系為 %s 失敗",
-    "Please install one of these locales on your system and restart your webserver." : "請在系統中安裝這些語系的其中一個，然後重啓網頁伺服器",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload 應該要被設定成 \"0\" 而不是目前的設定 \"%s\" ",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "為了修正這個問題，請到 php.ini 將 <code>mbstring.func_overload</code> 的值改為 <code>0</code>",
-    "PostgreSQL >= 9 required" : "需要 PostgreSQL 版本 >= 9",
-    "Please upgrade your database version" : "請升級您的資料庫版本",
-    "Your data directory is readable by other users" : "您的資料目錄可以被其他使用者讀取",
-    "Your data directory must be an absolute path" : "您的資料目錄必須為絕對路徑",
-    "Check the value of \"datadirectory\" in your configuration" : "請檢查您的設定檔中 \"datadirectory\" 的值",
-    "Your data directory is invalid" : "您的資料目錄無效"
+    "Free prompt" : "免費提示詞",
+    "Generate headline" : "產生標題",
+    "Generates a possible headline for a text." : "為文字產生可能的標題。",
+    "Summarize" : "總結",
+    "Summarizes text by reducing its length without losing key information." : "透過減少文字長度來總結而不遺失關鍵資訊。",
+    "Extract topics" : "擷取主題",
+    "Extracts topics from a text and outputs them separated by commas." : "從文字中擷取主題並輸出，然後用逗號分隔。",
+    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "應用程式 %1$s 中的檔案沒有被正確取代，請確認它的版本與伺服器相容。",
+    "Full name" : "全名",
+    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "已達使用者限制，所以未建立使用者。請檢查您的通知以取得更多資訊。",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "使用者名稱當中只能包含下列字元：\"a-z\", \"A-Z\", \"0-9\", 和 \"_.@-'\"",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 版本最低需求為 2.7.0。目前安裝版本為 %s 。",
+    "To fix this issue update your libxml2 version and restart your web server." : "修正方式為更新您的 libxml2 為 2.7.0 以上版本，再重啟網頁伺服器。"
 },
 "nplurals=1; plural=0;");
